@@ -430,3 +430,15 @@ class Utilities:
 	def clear_lock(self):
 		"""Clears the existing thread lock, making the current session thread-independent from others that might share the current thread lock."""
 		self._core.io.clear_lock()
+
+	def sync_from(self, source: 'Utilities') -> None:
+		"""Synchronises these Utils with the source."""
+		self.logger.sync_from(source.logger)
+		self.assign_lock(source.get_lock())
+		self.bin_float_numbers_format = source.bin_float_numbers_format
+		self.bin_int_numbers_format = source.bin_int_numbers_format
+		self.data_chunk_size = source.data_chunk_size
+		self.encoding = source.encoding
+		self.instrument_status_checking = source.instrument_status_checking
+		self.opc_query_after_write = source.opc_query_after_write
+		self.opc_timeout = source.opc_timeout
