@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Lower:
+class LowerCls:
 	"""Lower commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Lower:
 	def data(self):
 		"""data commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_data'):
-			from .Data import Data
-			self._data = Data(self._core, self._cmd_group)
+			from .Data import DataCls
+			self._data = DataCls(self._core, self._cmd_group)
 		return self._data
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def shift(self):
 		"""shift commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_shift'):
-			from .Shift import Shift
-			self._shift = Shift(self._core, self._cmd_group)
+			from .Shift import ShiftCls
+			self._shift = ShiftCls(self._core, self._cmd_group)
 		return self._shift
 
-	def clone(self) -> 'Lower':
+	def clone(self) -> 'LowerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Lower(self._core, self._cmd_group.parent)
+		new_group = LowerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
