@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Enr:
+class EnrCls:
 	"""Enr commands group definition. 6 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Enr:
 	def uncertainty(self):
 		"""uncertainty commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_uncertainty'):
-			from .Uncertainty import Uncertainty
-			self._uncertainty = Uncertainty(self._core, self._cmd_group)
+			from .Uncertainty import UncertaintyCls
+			self._uncertainty = UncertaintyCls(self._core, self._cmd_group)
 		return self._uncertainty
 
 	@property
 	def calibration(self):
 		"""calibration commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_calibration'):
-			from .Calibration import Calibration
-			self._calibration = Calibration(self._core, self._cmd_group)
+			from .Calibration import CalibrationCls
+			self._calibration = CalibrationCls(self._core, self._cmd_group)
 		return self._calibration
 
-	def clone(self) -> 'Enr':
+	def clone(self) -> 'EnrCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Enr(self._core, self._cmd_group.parent)
+		new_group = EnrCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
