@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sanalyzer:
+class SanalyzerCls:
 	"""Sanalyzer commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Sanalyzer:
 	def gain(self):
 		"""gain commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_gain'):
-			from .Gain import Gain
-			self._gain = Gain(self._core, self._cmd_group)
+			from .Gain import GainCls
+			self._gain = GainCls(self._core, self._cmd_group)
 		return self._gain
 
 	@property
 	def noise(self):
 		"""noise commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_noise'):
-			from .Noise import Noise
-			self._noise = Noise(self._core, self._cmd_group)
+			from .Noise import NoiseCls
+			self._noise = NoiseCls(self._core, self._cmd_group)
 		return self._noise
 
-	def clone(self) -> 'Sanalyzer':
+	def clone(self) -> 'SanalyzerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sanalyzer(self._core, self._cmd_group.parent)
+		new_group = SanalyzerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
