@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class ListPy:
+class ListPyCls:
 	"""ListPy commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class ListPy:
 	def data(self):
 		"""data commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_data'):
-			from .Data import Data
-			self._data = Data(self._core, self._cmd_group)
+			from .Data import DataCls
+			self._data = DataCls(self._core, self._cmd_group)
 		return self._data
 
-	def clone(self) -> 'ListPy':
+	def clone(self) -> 'ListPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = ListPy(self._core, self._cmd_group.parent)
+		new_group = ListPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
