@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Frequency:
+class FrequencyCls:
 	"""Frequency commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Frequency:
 	def continuous(self):
 		"""continuous commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_continuous'):
-			from .Continuous import Continuous
-			self._continuous = Continuous(self._core, self._cmd_group)
+			from .Continuous import ContinuousCls
+			self._continuous = ContinuousCls(self._core, self._cmd_group)
 		return self._continuous
 
 	@property
 	def single(self):
 		"""single commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_single'):
-			from .Single import Single
-			self._single = Single(self._core, self._cmd_group)
+			from .Single import SingleCls
+			self._single = SingleCls(self._core, self._cmd_group)
 		return self._single
 
-	def clone(self) -> 'Frequency':
+	def clone(self) -> 'FrequencyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Frequency(self._core, self._cmd_group.parent)
+		new_group = FrequencyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
