@@ -4,7 +4,7 @@ from ........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pcount:
+class PcountCls:
 	"""Pcount commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Pcount:
 		"""SCPI: [SENSe]:SWEep:EGATe:CONTinuous:PCOunt \n
 		Snippet: driver.applications.k30NoiseFigure.sense.sweep.egate.continuous.pcount.set(amount = 1.0) \n
 		Defines the number of gate periods to be measured after a single trigger event. \n
-			:param amount: integer Range: 1 to 1023
+			:param amount: integer Range: 1 to 65535
 		"""
 		param = Conversions.decimal_value_to_str(amount)
 		self._core.io.write(f'SENSe:SWEep:EGATe:CONTinuous:PCOunt {param}')
@@ -24,6 +24,6 @@ class Pcount:
 		"""SCPI: [SENSe]:SWEep:EGATe:CONTinuous:PCOunt \n
 		Snippet: value: float = driver.applications.k30NoiseFigure.sense.sweep.egate.continuous.pcount.get() \n
 		Defines the number of gate periods to be measured after a single trigger event. \n
-			:return: amount: integer Range: 1 to 1023"""
+			:return: amount: integer Range: 1 to 65535"""
 		response = self._core.io.query_str(f'SENSe:SWEep:EGATe:CONTinuous:PCOunt?')
 		return Conversions.str_to_float(response)
