@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sweep:
+class SweepCls:
 	"""Sweep commands group definition. 13 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Sweep:
 	def time(self):
 		"""time commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_time'):
-			from .Time import Time
-			self._time = Time(self._core, self._cmd_group)
+			from .Time import TimeCls
+			self._time = TimeCls(self._core, self._cmd_group)
 		return self._time
 
 	@property
 	def count(self):
 		"""count commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_count'):
-			from .Count import Count
-			self._count = Count(self._core, self._cmd_group)
+			from .Count import CountCls
+			self._count = CountCls(self._core, self._cmd_group)
 		return self._count
 
 	@property
 	def egate(self):
 		"""egate commands group. 8 Sub-classes, 1 commands."""
 		if not hasattr(self, '_egate'):
-			from .Egate import Egate
-			self._egate = Egate(self._core, self._cmd_group)
+			from .Egate import EgateCls
+			self._egate = EgateCls(self._core, self._cmd_group)
 		return self._egate
 
-	def clone(self) -> 'Sweep':
+	def clone(self) -> 'SweepCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sweep(self._core, self._cmd_group.parent)
+		new_group = SweepCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
