@@ -3,8 +3,8 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class System:
-	"""System commands group definition. 12 total commands, 3 Subgroups, 0 group commands"""
+class SystemCls:
+	"""System commands group definition. 11 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,30 +14,22 @@ class System:
 	def communicate(self):
 		"""communicate commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_communicate'):
-			from .Communicate import Communicate
-			self._communicate = Communicate(self._core, self._cmd_group)
+			from .Communicate import CommunicateCls
+			self._communicate = CommunicateCls(self._core, self._cmd_group)
 		return self._communicate
 
 	@property
 	def configure(self):
 		"""configure commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_configure'):
-			from .Configure import Configure
-			self._configure = Configure(self._core, self._cmd_group)
+			from .Configure import ConfigureCls
+			self._configure = ConfigureCls(self._core, self._cmd_group)
 		return self._configure
 
-	@property
-	def preset(self):
-		"""preset commands group. 1 Sub-classes, 0 commands."""
-		if not hasattr(self, '_preset'):
-			from .Preset import Preset
-			self._preset = Preset(self._core, self._cmd_group)
-		return self._preset
-
-	def clone(self) -> 'System':
+	def clone(self) -> 'SystemCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = System(self._core, self._cmd_group.parent)
+		new_group = SystemCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
