@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Sense:
+class SenseCls:
 	"""Sense commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Sense:
 	def probe(self):
 		"""probe commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_probe'):
-			from .Probe import Probe
-			self._probe = Probe(self._core, self._cmd_group)
+			from .Probe import ProbeCls
+			self._probe = ProbeCls(self._core, self._cmd_group)
 		return self._probe
 
-	def clone(self) -> 'Sense':
+	def clone(self) -> 'SenseCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Sense(self._core, self._cmd_group.parent)
+		new_group = SenseCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
