@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class LinkTo:
+class LinkToCls:
 	"""LinkTo commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class LinkTo:
 	def marker(self):
 		"""marker commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_marker'):
-			from .Marker import Marker
-			self._marker = Marker(self._core, self._cmd_group)
+			from .Marker import MarkerCls
+			self._marker = MarkerCls(self._core, self._cmd_group)
 		return self._marker
 
-	def clone(self) -> 'LinkTo':
+	def clone(self) -> 'LinkToCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = LinkTo(self._core, self._cmd_group.parent)
+		new_group = LinkToCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
