@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Table:
+class TableCls:
 	"""Table commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Table:
 	def column(self):
 		"""column commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_column'):
-			from .Column import Column
-			self._column = Column(self._core, self._cmd_group)
+			from .Column import ColumnCls
+			self._column = ColumnCls(self._core, self._cmd_group)
 		return self._column
 
-	def clone(self) -> 'Table':
+	def clone(self) -> 'TableCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Table(self._core, self._cmd_group.parent)
+		new_group = TableCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
