@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Zero:
+class ZeroCls:
 	"""Zero commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Zero:
 	def auto(self):
 		"""auto commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_auto'):
-			from .Auto import Auto
-			self._auto = Auto(self._core, self._cmd_group)
+			from .Auto import AutoCls
+			self._auto = AutoCls(self._core, self._cmd_group)
 		return self._auto
 
-	def clone(self) -> 'Zero':
+	def clone(self) -> 'ZeroCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Zero(self._core, self._cmd_group.parent)
+		new_group = ZeroCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
