@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Calibration:
+class CalibrationCls:
 	"""Calibration commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Calibration:
 	def pmeter(self):
 		"""pmeter commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_pmeter'):
-			from .Pmeter import Pmeter
-			self._pmeter = Pmeter(self._core, self._cmd_group)
+			from .Pmeter import PmeterCls
+			self._pmeter = PmeterCls(self._core, self._cmd_group)
 		return self._pmeter
 
-	def clone(self) -> 'Calibration':
+	def clone(self) -> 'CalibrationCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Calibration(self._core, self._cmd_group.parent)
+		new_group = CalibrationCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
