@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Guard:
+class GuardCls:
 	"""Guard commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Guard:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def interval(self):
 		"""interval commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_interval'):
-			from .Interval import Interval
-			self._interval = Interval(self._core, self._cmd_group)
+			from .Interval import IntervalCls
+			self._interval = IntervalCls(self._core, self._cmd_group)
 		return self._interval
 
-	def clone(self) -> 'Guard':
+	def clone(self) -> 'GuardCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Guard(self._core, self._cmd_group.parent)
+		new_group = GuardCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
