@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Measure:
+class MeasureCls:
 	"""Measure commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Measure:
 	def points(self):
 		"""points commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_points'):
-			from .Points import Points
-			self._points = Points(self._core, self._cmd_group)
+			from .Points import PointsCls
+			self._points = PointsCls(self._core, self._cmd_group)
 		return self._points
 
-	def clone(self) -> 'Measure':
+	def clone(self) -> 'MeasureCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Measure(self._core, self._cmd_group.parent)
+		new_group = MeasureCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
