@@ -4,7 +4,7 @@ from ........Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Value:
+class ValueCls:
 	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Value:
 		"""SCPI: [SENSe]:MIXer:HARMonic:HIGH[:VALue] \n
 		Snippet: driver.applications.k50Spurious.sense.mixer.harmonic.high.value.set(freq_high = 1.0) \n
 		This command specifies the harmonic order to be used for the high (second) range. \n
-			:param freq_high: 1..n irrelevant
+			:param freq_high: No help available
 		"""
 		param = Conversions.decimal_value_to_str(freq_high)
 		self._core.io.write(f'SENSe:MIXer:HARMonic:HIGH:VALue {param}')
