@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Distribution:
+class DistributionCls:
 	"""Distribution commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Distribution:
 	def nbins(self):
 		"""nbins commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_nbins'):
-			from .Nbins import Nbins
-			self._nbins = Nbins(self._core, self._cmd_group)
+			from .Nbins import NbinsCls
+			self._nbins = NbinsCls(self._core, self._cmd_group)
 		return self._nbins
 
-	def clone(self) -> 'Distribution':
+	def clone(self) -> 'DistributionCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Distribution(self._core, self._cmd_group.parent)
+		new_group = DistributionCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
