@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Color:
+class ColorCls:
 	"""Color commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Color:
 	def style(self):
 		"""style commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_style'):
-			from .Style import Style
-			self._style = Style(self._core, self._cmd_group)
+			from .Style import StyleCls
+			self._style = StyleCls(self._core, self._cmd_group)
 		return self._style
 
-	def clone(self) -> 'Color':
+	def clone(self) -> 'ColorCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Color(self._core, self._cmd_group.parent)
+		new_group = ColorCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
