@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Spectrogram:
+class SpectrogramCls:
 	"""Spectrogram commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Spectrogram:
 	def color(self):
 		"""color commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_color'):
-			from .Color import Color
-			self._color = Color(self._core, self._cmd_group)
+			from .Color import ColorCls
+			self._color = ColorCls(self._core, self._cmd_group)
 		return self._color
 
-	def clone(self) -> 'Spectrogram':
+	def clone(self) -> 'SpectrogramCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Spectrogram(self._core, self._cmd_group.parent)
+		new_group = SpectrogramCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
