@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Egain:
+class EgainCls:
 	"""Egain commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Egain:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def bypass(self):
 		"""bypass commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_bypass'):
-			from .Bypass import Bypass
-			self._bypass = Bypass(self._core, self._cmd_group)
+			from .Bypass import BypassCls
+			self._bypass = BypassCls(self._core, self._cmd_group)
 		return self._bypass
 
-	def clone(self) -> 'Egain':
+	def clone(self) -> 'EgainCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Egain(self._core, self._cmd_group.parent)
+		new_group = EgainCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
