@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iqhs:
+class IqhsCls:
 	"""Iqhs commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Iqhs:
 	def symbolRate(self):
 		"""symbolRate commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_symbolRate'):
-			from .SymbolRate import SymbolRate
-			self._symbolRate = SymbolRate(self._core, self._cmd_group)
+			from .SymbolRate import SymbolRateCls
+			self._symbolRate = SymbolRateCls(self._core, self._cmd_group)
 		return self._symbolRate
 
 	@property
 	def cdevice(self):
 		"""cdevice commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cdevice'):
-			from .Cdevice import Cdevice
-			self._cdevice = Cdevice(self._core, self._cmd_group)
+			from .Cdevice import CdeviceCls
+			self._cdevice = CdeviceCls(self._core, self._cmd_group)
 		return self._cdevice
 
-	def clone(self) -> 'Iqhs':
+	def clone(self) -> 'IqhsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iqhs(self._core, self._cmd_group.parent)
+		new_group = IqhsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
