@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class X:
+class XCls:
 	"""X commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class X:
 	def absolute(self):
 		"""absolute commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_absolute'):
-			from .Absolute import Absolute
-			self._absolute = Absolute(self._core, self._cmd_group)
+			from .Absolute import AbsoluteCls
+			self._absolute = AbsoluteCls(self._core, self._cmd_group)
 		return self._absolute
 
 	@property
 	def relative(self):
 		"""relative commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_relative'):
-			from .Relative import Relative
-			self._relative = Relative(self._core, self._cmd_group)
+			from .Relative import RelativeCls
+			self._relative = RelativeCls(self._core, self._cmd_group)
 		return self._relative
 
-	def clone(self) -> 'X':
+	def clone(self) -> 'XCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = X(self._core, self._cmd_group.parent)
+		new_group = XCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
