@@ -3,7 +3,7 @@ from ..........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Burst:
+class BurstCls:
 	"""Burst commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Burst:
 	def start(self):
 		"""start commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_start'):
-			from .Start import Start
-			self._start = Start(self._core, self._cmd_group)
+			from .Start import StartCls
+			self._start = StartCls(self._core, self._cmd_group)
 		return self._start
 
 	@property
 	def length(self):
 		"""length commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_length'):
-			from .Length import Length
-			self._length = Length(self._core, self._cmd_group)
+			from .Length import LengthCls
+			self._length = LengthCls(self._core, self._cmd_group)
 		return self._length
 
 	@property
 	def present(self):
 		"""present commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_present'):
-			from .Present import Present
-			self._present = Present(self._core, self._cmd_group)
+			from .Present import PresentCls
+			self._present = PresentCls(self._core, self._cmd_group)
 		return self._present
 
-	def clone(self) -> 'Burst':
+	def clone(self) -> 'BurstCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Burst(self._core, self._cmd_group.parent)
+		new_group = BurstCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
