@@ -5,7 +5,7 @@ from .......... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Confidence:
+class ConfidenceCls:
 	"""Confidence commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
