@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Fsk:
+class FskCls:
 	"""Fsk commands group definition. 3 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Fsk:
 	def deviation(self):
 		"""deviation commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_deviation'):
-			from .Deviation import Deviation
-			self._deviation = Deviation(self._core, self._cmd_group)
+			from .Deviation import DeviationCls
+			self._deviation = DeviationCls(self._core, self._cmd_group)
 		return self._deviation
 
-	def clone(self) -> 'Fsk':
+	def clone(self) -> 'FskCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Fsk(self._core, self._cmd_group.parent)
+		new_group = FskCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
