@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class CfError:
+class CfErrorCls:
 	"""CfError commands group definition. 9 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class CfError:
 	def current(self):
 		"""current commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_current'):
-			from .Current import Current
-			self._current = Current(self._core, self._cmd_group)
+			from .Current import CurrentCls
+			self._current = CurrentCls(self._core, self._cmd_group)
 		return self._current
 
 	@property
 	def mean(self):
 		"""mean commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_mean'):
-			from .Mean import Mean
-			self._mean = Mean(self._core, self._cmd_group)
+			from .Mean import MeanCls
+			self._mean = MeanCls(self._core, self._cmd_group)
 		return self._mean
 
 	@property
 	def peak(self):
 		"""peak commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_peak'):
-			from .Peak import Peak
-			self._peak = Peak(self._core, self._cmd_group)
+			from .Peak import PeakCls
+			self._peak = PeakCls(self._core, self._cmd_group)
 		return self._peak
 
-	def clone(self) -> 'CfError':
+	def clone(self) -> 'CfErrorCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = CfError(self._core, self._cmd_group.parent)
+		new_group = CfErrorCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
