@@ -5,7 +5,7 @@ from ......... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Result:
+class ResultCls:
 	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,7 +16,7 @@ class Result:
 		"""SCPI: CALCulate<n>:LIMit:MACCuracy:FERRor:RCURrent[:RESult] \n
 		Snippet: value: str = driver.applications.k70Vsa.calculate.limit.maccuracy.freqError.rcurrent.result.get(window = repcap.Window.Default) \n
 		This command queries whether the limit for the specified result type and limit type was violated. For details on result
-		types and limit types see 'Result Summary'. \n
+		types and limit types see 'Result summary'. \n
 			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
 			:return: result: No help available"""
 		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
