@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ddemod:
+class DdemodCls:
 	"""Ddemod commands group definition. 20 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Ddemod:
 	def result(self):
 		"""result commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_result'):
-			from .Result import Result
-			self._result = Result(self._core, self._cmd_group)
+			from .Result import ResultCls
+			self._result = ResultCls(self._core, self._cmd_group)
 		return self._result
 
 	@property
 	def statistic(self):
 		"""statistic commands group. 16 Sub-classes, 0 commands."""
 		if not hasattr(self, '_statistic'):
-			from .Statistic import Statistic
-			self._statistic = Statistic(self._core, self._cmd_group)
+			from .Statistic import StatisticCls
+			self._statistic = StatisticCls(self._core, self._cmd_group)
 		return self._statistic
 
-	def clone(self) -> 'Ddemod':
+	def clone(self) -> 'DdemodCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ddemod(self._core, self._cmd_group.parent)
+		new_group = DdemodCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
