@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Function:
+class FunctionCls:
 	"""Function commands group definition. 20 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Function:
 	def ddemod(self):
 		"""ddemod commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_ddemod'):
-			from .Ddemod import Ddemod
-			self._ddemod = Ddemod(self._core, self._cmd_group)
+			from .Ddemod import DdemodCls
+			self._ddemod = DdemodCls(self._core, self._cmd_group)
 		return self._ddemod
 
-	def clone(self) -> 'Function':
+	def clone(self) -> 'FunctionCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Function(self._core, self._cmd_group.parent)
+		new_group = FunctionCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
