@@ -4,7 +4,7 @@ from ....... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Right:
+class RightCls:
 	"""Right commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,8 +14,8 @@ class Right:
 	def set(self, window=repcap.Window.Default, marker=repcap.Marker.Default, opc_timeout_ms: int = -1) -> None:
 		"""SCPI: CALCulate<n>:MARKer<m>:MINimum:RIGHt \n
 		Snippet: driver.applications.k70Vsa.calculate.marker.minimum.right.set(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
-		This command moves a marker to the next minimum value. The search includes only measurement values to the right of the
-		current marker position. \n
+		This command moves a marker to the next minimum peak value. The search includes only measurement values to the right of
+		the current marker position. \n
 			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
 			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
 			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
