@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Window:
+class WindowCls:
 	"""Window commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Window:
 	def ival(self):
 		"""ival commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ival'):
-			from .Ival import Ival
-			self._ival = Ival(self._core, self._cmd_group)
+			from .Ival import IvalCls
+			self._ival = IvalCls(self._core, self._cmd_group)
 		return self._ival
 
-	def clone(self) -> 'Window':
+	def clone(self) -> 'WindowCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Window(self._core, self._cmd_group.parent)
+		new_group = WindowCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
