@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class X:
+class XCls:
 	"""X commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class X:
 	def bcount(self):
 		"""bcount commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_bcount'):
-			from .Bcount import Bcount
-			self._bcount = Bcount(self._core, self._cmd_group)
+			from .Bcount import BcountCls
+			self._bcount = BcountCls(self._core, self._cmd_group)
 		return self._bcount
 
-	def clone(self) -> 'X':
+	def clone(self) -> 'XCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = X(self._core, self._cmd_group.parent)
+		new_group = XCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
