@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Scale:
+class ScaleCls:
 	"""Scale commands group definition. 4 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Scale:
 	def x(self):
 		"""x commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_x'):
-			from .X import X
-			self._x = X(self._core, self._cmd_group)
+			from .X import XCls
+			self._x = XCls(self._core, self._cmd_group)
 		return self._x
 
 	@property
 	def y(self):
 		"""y commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_y'):
-			from .Y import Y
-			self._y = Y(self._core, self._cmd_group)
+			from .Y import YCls
+			self._y = YCls(self._core, self._cmd_group)
 		return self._y
 
-	def clone(self) -> 'Scale':
+	def clone(self) -> 'ScaleCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Scale(self._core, self._cmd_group.parent)
+		new_group = ScaleCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
