@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Adjust:
+class AdjustCls:
 	"""Adjust commands group definition. 3 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Adjust:
 	def value(self):
 		"""value commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_value'):
-			from .Value import Value
-			self._value = Value(self._core, self._cmd_group)
+			from .Value import ValueCls
+			self._value = ValueCls(self._core, self._cmd_group)
 		return self._value
 
 	@property
 	def alignment(self):
 		"""alignment commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_alignment'):
-			from .Alignment import Alignment
-			self._alignment = Alignment(self._core, self._cmd_group)
+			from .Alignment import AlignmentCls
+			self._alignment = AlignmentCls(self._core, self._cmd_group)
 		return self._alignment
 
-	def clone(self) -> 'Adjust':
+	def clone(self) -> 'AdjustCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Adjust(self._core, self._cmd_group.parent)
+		new_group = AdjustCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
