@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Unit:
+class UnitCls:
 	"""Unit commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Unit:
 	def angle(self):
 		"""angle commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_angle'):
-			from .Angle import Angle
-			self._angle = Angle(self._core, self._cmd_group)
+			from .Angle import AngleCls
+			self._angle = AngleCls(self._core, self._cmd_group)
 		return self._angle
 
 	@property
 	def power(self):
 		"""power commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_power'):
-			from .Power import Power
-			self._power = Power(self._core, self._cmd_group)
+			from .Power import PowerCls
+			self._power = PowerCls(self._core, self._cmd_group)
 		return self._power
 
-	def clone(self) -> 'Unit':
+	def clone(self) -> 'UnitCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Unit(self._core, self._cmd_group.parent)
+		new_group = UnitCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
