@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Dexport:
+class DexportCls:
 	"""Dexport commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Dexport:
 	def dseparator(self):
 		"""dseparator commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_dseparator'):
-			from .Dseparator import Dseparator
-			self._dseparator = Dseparator(self._core, self._cmd_group)
+			from .Dseparator import DseparatorCls
+			self._dseparator = DseparatorCls(self._core, self._cmd_group)
 		return self._dseparator
 
 	@property
 	def header(self):
 		"""header commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_header'):
-			from .Header import Header
-			self._header = Header(self._core, self._cmd_group)
+			from .Header import HeaderCls
+			self._header = HeaderCls(self._core, self._cmd_group)
 		return self._header
 
 	@property
 	def mode(self):
 		"""mode commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_mode'):
-			from .Mode import Mode
-			self._mode = Mode(self._core, self._cmd_group)
+			from .Mode import ModeCls
+			self._mode = ModeCls(self._core, self._cmd_group)
 		return self._mode
 
-	def clone(self) -> 'Dexport':
+	def clone(self) -> 'DexportCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Dexport(self._core, self._cmd_group.parent)
+		new_group = DexportCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
