@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Kdata:
+class KdataCls:
 	"""Kdata commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Kdata:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def name(self):
 		"""name commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_name'):
-			from .Name import Name
-			self._name = Name(self._core, self._cmd_group)
+			from .Name import NameCls
+			self._name = NameCls(self._core, self._cmd_group)
 		return self._name
 
 	@property
 	def ser(self):
 		"""ser commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_ser'):
-			from .Ser import Ser
-			self._ser = Ser(self._core, self._cmd_group)
+			from .Ser import SerCls
+			self._ser = SerCls(self._core, self._cmd_group)
 		return self._ser
 
-	def clone(self) -> 'Kdata':
+	def clone(self) -> 'KdataCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Kdata(self._core, self._cmd_group.parent)
+		new_group = KdataCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
