@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Qam:
+class QamCls:
 	"""Qam commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Qam:
 	def formatPy(self):
 		"""formatPy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_formatPy'):
-			from .FormatPy import FormatPy
-			self._formatPy = FormatPy(self._core, self._cmd_group)
+			from .FormatPy import FormatPyCls
+			self._formatPy = FormatPyCls(self._core, self._cmd_group)
 		return self._formatPy
 
 	@property
 	def nstate(self):
 		"""nstate commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_nstate'):
-			from .Nstate import Nstate
-			self._nstate = Nstate(self._core, self._cmd_group)
+			from .Nstate import NstateCls
+			self._nstate = NstateCls(self._core, self._cmd_group)
 		return self._nstate
 
-	def clone(self) -> 'Qam':
+	def clone(self) -> 'QamCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Qam(self._core, self._cmd_group.parent)
+		new_group = QamCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
