@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class User:
+class UserCls:
 	"""User commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class User:
 	def name(self):
 		"""name commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_name'):
-			from .Name import Name
-			self._name = Name(self._core, self._cmd_group)
+			from .Name import NameCls
+			self._name = NameCls(self._core, self._cmd_group)
 		return self._name
 
-	def clone(self) -> 'User':
+	def clone(self) -> 'UserCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = User(self._core, self._cmd_group.parent)
+		new_group = UserCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
