@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Preset:
+class PresetCls:
 	"""Preset commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Preset:
 	def calc(self):
 		"""calc commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_calc'):
-			from .Calc import Calc
-			self._calc = Calc(self._core, self._cmd_group)
+			from .Calc import CalcCls
+			self._calc = CalcCls(self._core, self._cmd_group)
 		return self._calc
 
 	@property
 	def refLevel(self):
 		"""refLevel commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_refLevel'):
-			from .RefLevel import RefLevel
-			self._refLevel = RefLevel(self._core, self._cmd_group)
+			from .RefLevel import RefLevelCls
+			self._refLevel = RefLevelCls(self._core, self._cmd_group)
 		return self._refLevel
 
 	@property
 	def standard(self):
 		"""standard commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_standard'):
-			from .Standard import Standard
-			self._standard = Standard(self._core, self._cmd_group)
+			from .Standard import StandardCls
+			self._standard = StandardCls(self._core, self._cmd_group)
 		return self._standard
 
-	def clone(self) -> 'Preset':
+	def clone(self) -> 'PresetCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Preset(self._core, self._cmd_group.parent)
+		new_group = PresetCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
