@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rlength:
+class RlengthCls:
 	"""Rlength commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Rlength:
 	def value(self):
 		"""value commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_value'):
-			from .Value import Value
-			self._value = Value(self._core, self._cmd_group)
+			from .Value import ValueCls
+			self._value = ValueCls(self._core, self._cmd_group)
 		return self._value
 
 	@property
 	def symbols(self):
 		"""symbols commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_symbols'):
-			from .Symbols import Symbols
-			self._symbols = Symbols(self._core, self._cmd_group)
+			from .Symbols import SymbolsCls
+			self._symbols = SymbolsCls(self._core, self._cmd_group)
 		return self._symbols
 
 	@property
 	def auto(self):
 		"""auto commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_auto'):
-			from .Auto import Auto
-			self._auto = Auto(self._core, self._cmd_group)
+			from .Auto import AutoCls
+			self._auto = AutoCls(self._core, self._cmd_group)
 		return self._auto
 
-	def clone(self) -> 'Rlength':
+	def clone(self) -> 'RlengthCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rlength(self._core, self._cmd_group.parent)
+		new_group = RlengthCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
