@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Frequency:
+class FrequencyCls:
 	"""Frequency commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Frequency:
 	def offset(self):
 		"""offset commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_offset'):
-			from .Offset import Offset
-			self._offset = Offset(self._core, self._cmd_group)
+			from .Offset import OffsetCls
+			self._offset = OffsetCls(self._core, self._cmd_group)
 		return self._offset
 
 	@property
 	def center(self):
 		"""center commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_center'):
-			from .Center import Center
-			self._center = Center(self._core, self._cmd_group)
+			from .Center import CenterCls
+			self._center = CenterCls(self._core, self._cmd_group)
 		return self._center
 
-	def clone(self) -> 'Frequency':
+	def clone(self) -> 'FrequencyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Frequency(self._core, self._cmd_group.parent)
+		new_group = FrequencyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
