@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Tcapture:
+class TcaptureCls:
 	"""Tcapture commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Tcapture:
 	def length(self):
 		"""length commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_length'):
-			from .Length import Length
-			self._length = Length(self._core, self._cmd_group)
+			from .Length import LengthCls
+			self._length = LengthCls(self._core, self._cmd_group)
 		return self._length
 
-	def clone(self) -> 'Tcapture':
+	def clone(self) -> 'TcaptureCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Tcapture(self._core, self._cmd_group.parent)
+		new_group = TcaptureCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
