@@ -4,7 +4,7 @@ from ......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Window:
+class WindowCls:
 	"""Window commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Window:
 		"""SCPI: LAYout:IDENtify[:WINDow] \n
 		Snippet: value: int = driver.applications.k7AnalogDemod.layout.identify.window.get(window_name = '1') \n
 		This command queries the index of a particular display window in the active channel. Note: to query the name of a
-		particular window, use the LAYout:WINDow<n>:IDENtify query. \n
+		particular window, use the LAYout:WINDow<n>:IDENtify? query. \n
 			:param window_name: String containing the name of a window.
 			:return: window_index: Index number of the window."""
 		param = Conversions.value_to_quoted_str(window_name)
