@@ -3,7 +3,7 @@ from ........Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Maximum:
+class MaximumCls:
 	"""Maximum commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Maximum:
 	def peak(self):
 		"""peak commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_peak'):
-			from .Peak import Peak
-			self._peak = Peak(self._core, self._cmd_group)
+			from .Peak import PeakCls
+			self._peak = PeakCls(self._core, self._cmd_group)
 		return self._peak
 
-	def clone(self) -> 'Maximum':
+	def clone(self) -> 'MaximumCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Maximum(self._core, self._cmd_group.parent)
+		new_group = MaximumCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
