@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pnoise:
+class PnoiseCls:
 	"""Pnoise commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Pnoise:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def result(self):
 		"""result commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_result'):
-			from .Result import Result
-			self._result = Result(self._core, self._cmd_group)
+			from .Result import ResultCls
+			self._result = ResultCls(self._core, self._cmd_group)
 		return self._result
 
 	@property
 	def auto(self):
 		"""auto commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_auto'):
-			from .Auto import Auto
-			self._auto = Auto(self._core, self._cmd_group)
+			from .Auto import AutoCls
+			self._auto = AutoCls(self._core, self._cmd_group)
 		return self._auto
 
-	def clone(self) -> 'Pnoise':
+	def clone(self) -> 'PnoiseCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Pnoise(self._core, self._cmd_group.parent)
+		new_group = PnoiseCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
