@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Distortion:
+class DistortionCls:
 	"""Distortion commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Distortion:
 	def write(self):
 		"""write commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_write'):
-			from .Write import Write
-			self._write = Write(self._core, self._cmd_group)
+			from .Write import WriteCls
+			self._write = WriteCls(self._core, self._cmd_group)
 		return self._write
 
-	def clone(self) -> 'Distortion':
+	def clone(self) -> 'DistortionCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Distortion(self._core, self._cmd_group.parent)
+		new_group = DistortionCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
