@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Noise:
+class NoiseCls:
 	"""Noise commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Noise:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def result(self):
 		"""result commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_result'):
-			from .Result import Result
-			self._result = Result(self._core, self._cmd_group)
+			from .Result import ResultCls
+			self._result = ResultCls(self._core, self._cmd_group)
 		return self._result
 
 	@property
 	def aoff(self):
 		"""aoff commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_aoff'):
-			from .Aoff import Aoff
-			self._aoff = Aoff(self._core, self._cmd_group)
+			from .Aoff import AoffCls
+			self._aoff = AoffCls(self._core, self._cmd_group)
 		return self._aoff
 
-	def clone(self) -> 'Noise':
+	def clone(self) -> 'NoiseCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Noise(self._core, self._cmd_group.parent)
+		new_group = NoiseCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
