@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Auto:
+class AutoCls:
 	"""Auto commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Auto:
 	def listPy(self):
 		"""listPy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_listPy'):
-			from .ListPy import ListPy
-			self._listPy = ListPy(self._core, self._cmd_group)
+			from .ListPy import ListPyCls
+			self._listPy = ListPyCls(self._core, self._cmd_group)
 		return self._listPy
 
-	def clone(self) -> 'Auto':
+	def clone(self) -> 'AutoCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Auto(self._core, self._cmd_group.parent)
+		new_group = AutoCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
