@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Strack:
+class StrackCls:
 	"""Strack commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Strack:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def threshold(self):
 		"""threshold commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_threshold'):
-			from .Threshold import Threshold
-			self._threshold = Threshold(self._core, self._cmd_group)
+			from .Threshold import ThresholdCls
+			self._threshold = ThresholdCls(self._core, self._cmd_group)
 		return self._threshold
 
 	@property
 	def trace(self):
 		"""trace commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_trace'):
-			from .Trace import Trace
-			self._trace = Trace(self._core, self._cmd_group)
+			from .Trace import TraceCls
+			self._trace = TraceCls(self._core, self._cmd_group)
 		return self._trace
 
-	def clone(self) -> 'Strack':
+	def clone(self) -> 'StrackCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Strack(self._core, self._cmd_group.parent)
+		new_group = StrackCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
