@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Relative:
+class RelativeCls:
 	"""Relative commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Relative:
 	def magnitude(self):
 		"""magnitude commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_magnitude'):
-			from .Magnitude import Magnitude
-			self._magnitude = Magnitude(self._core, self._cmd_group)
+			from .Magnitude import MagnitudeCls
+			self._magnitude = MagnitudeCls(self._core, self._cmd_group)
 		return self._magnitude
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'Relative':
+	def clone(self) -> 'RelativeCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Relative(self._core, self._cmd_group.parent)
+		new_group = RelativeCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
