@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rtms:
+class RtmsCls:
 	"""Rtms commands group definition. 3 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Rtms:
 	def aline(self):
 		"""aline commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_aline'):
-			from .Aline import Aline
-			self._aline = Aline(self._core, self._cmd_group)
+			from .Aline import AlineCls
+			self._aline = AlineCls(self._core, self._cmd_group)
 		return self._aline
 
 	@property
 	def window(self):
 		"""window commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_window'):
-			from .Window import Window
-			self._window = Window(self._core, self._cmd_group)
+			from .Window import WindowCls
+			self._window = WindowCls(self._core, self._cmd_group)
 		return self._window
 
-	def clone(self) -> 'Rtms':
+	def clone(self) -> 'RtmsCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rtms(self._core, self._cmd_group.parent)
+		new_group = RtmsCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
