@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Aiq:
+class AiqCls:
 	"""Aiq commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Aiq:
 	def haTiming(self):
 		"""haTiming commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_haTiming'):
-			from .HaTiming import HaTiming
-			self._haTiming = HaTiming(self._core, self._cmd_group)
+			from .HaTiming import HaTimingCls
+			self._haTiming = HaTimingCls(self._core, self._cmd_group)
 		return self._haTiming
 
-	def clone(self) -> 'Aiq':
+	def clone(self) -> 'AiqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Aiq(self._core, self._cmd_group.parent)
+		new_group = AiqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
