@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Am:
+class AmCls:
 	"""Am commands group definition. 4 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Am:
 	def detector(self):
 		"""detector commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_detector'):
-			from .Detector import Detector
-			self._detector = Detector(self._core, self._cmd_group)
+			from .Detector import DetectorCls
+			self._detector = DetectorCls(self._core, self._cmd_group)
 		return self._detector
 
-	def clone(self) -> 'Am':
+	def clone(self) -> 'AmCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Am(self._core, self._cmd_group.parent)
+		new_group = AmCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
