@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ademod:
+class AdemodCls:
 	"""Ademod commands group definition. 13 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Ademod:
 	def results(self):
 		"""results commands group. 4 Sub-classes, 0 commands."""
 		if not hasattr(self, '_results'):
-			from .Results import Results
-			self._results = Results(self._core, self._cmd_group)
+			from .Results import ResultsCls
+			self._results = ResultsCls(self._core, self._cmd_group)
 		return self._results
 
-	def clone(self) -> 'Ademod':
+	def clone(self) -> 'AdemodCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ademod(self._core, self._cmd_group.parent)
+		new_group = AdemodCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
