@@ -3,8 +3,8 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Generator:
-	"""Generator commands group definition. 3 total commands, 2 Subgroups, 0 group commands"""
+class GeneratorCls:
+	"""Generator commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,22 +14,30 @@ class Generator:
 	def connection(self):
 		"""connection commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_connection'):
-			from .Connection import Connection
-			self._connection = Connection(self._core, self._cmd_group)
+			from .Connection import ConnectionCls
+			self._connection = ConnectionCls(self._core, self._cmd_group)
 		return self._connection
 
 	@property
 	def ipConnection(self):
 		"""ipConnection commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_ipConnection'):
-			from .IpConnection import IpConnection
-			self._ipConnection = IpConnection(self._core, self._cmd_group)
+			from .IpConnection import IpConnectionCls
+			self._ipConnection = IpConnectionCls(self._core, self._cmd_group)
 		return self._ipConnection
 
-	def clone(self) -> 'Generator':
+	@property
+	def recording(self):
+		"""recording commands group. 1 Sub-classes, 0 commands."""
+		if not hasattr(self, '_recording'):
+			from .Recording import RecordingCls
+			self._recording = RecordingCls(self._core, self._cmd_group)
+		return self._recording
+
+	def clone(self) -> 'GeneratorCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Generator(self._core, self._cmd_group.parent)
+		new_group = GeneratorCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
