@@ -3,8 +3,8 @@ from ...Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Configure:
-	"""Configure commands group definition. 16 total commands, 2 Subgroups, 0 group commands"""
+class ConfigureCls:
+	"""Configure commands group definition. 17 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
@@ -14,22 +14,22 @@ class Configure:
 	def ademod(self):
 		"""ademod commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_ademod'):
-			from .Ademod import Ademod
-			self._ademod = Ademod(self._core, self._cmd_group)
+			from .Ademod import AdemodCls
+			self._ademod = AdemodCls(self._core, self._cmd_group)
 		return self._ademod
 
 	@property
 	def generator(self):
-		"""generator commands group. 2 Sub-classes, 0 commands."""
+		"""generator commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_generator'):
-			from .Generator import Generator
-			self._generator = Generator(self._core, self._cmd_group)
+			from .Generator import GeneratorCls
+			self._generator = GeneratorCls(self._core, self._cmd_group)
 		return self._generator
 
-	def clone(self) -> 'Configure':
+	def clone(self) -> 'ConfigureCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Configure(self._core, self._cmd_group.parent)
+		new_group = ConfigureCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
