@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Device:
+class DeviceCls:
 	"""Device commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Device:
 	def history(self):
 		"""history commands group. 0 Sub-classes, 2 commands."""
 		if not hasattr(self, '_history'):
-			from .History import History
-			self._history = History(self._core, self._cmd_group)
+			from .History import HistoryCls
+			self._history = HistoryCls(self._core, self._cmd_group)
 		return self._history
 
-	def clone(self) -> 'Device':
+	def clone(self) -> 'DeviceCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Device(self._core, self._cmd_group.parent)
+		new_group = DeviceCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
