@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Status:
+class StatusCls:
 	"""Status commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,8 +14,8 @@ class Status:
 	def summary(self):
 		"""summary commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_summary'):
-			from .Summary import Summary
-			self._summary = Summary(self._core, self._cmd_group)
+			from .Summary import SummaryCls
+			self._summary = SummaryCls(self._core, self._cmd_group)
 		return self._summary
 
 	def get(self) -> bytes:
@@ -26,10 +26,10 @@ class Status:
 		response = self._core.io.query_bin_block_ERROR(f'DIAGnostic:HUMS:SYSTem:STATus?')
 		return response
 
-	def clone(self) -> 'Status':
+	def clone(self) -> 'StatusCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Status(self._core, self._cmd_group.parent)
+		new_group = StatusCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
