@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Annotation:
+class AnnotationCls:
 	"""Annotation commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Annotation:
 	def frequency(self):
 		"""frequency commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_frequency'):
-			from .Frequency import Frequency
-			self._frequency = Frequency(self._core, self._cmd_group)
+			from .Frequency import FrequencyCls
+			self._frequency = FrequencyCls(self._core, self._cmd_group)
 		return self._frequency
 
 	@property
 	def cbar(self):
 		"""cbar commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cbar'):
-			from .Cbar import Cbar
-			self._cbar = Cbar(self._core, self._cmd_group)
+			from .Cbar import CbarCls
+			self._cbar = CbarCls(self._core, self._cmd_group)
 		return self._cbar
 
-	def clone(self) -> 'Annotation':
+	def clone(self) -> 'AnnotationCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Annotation(self._core, self._cmd_group.parent)
+		new_group = AnnotationCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
