@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class PreSelector:
+class PreSelectorCls:
 	"""PreSelector commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class PreSelector:
 	def position(self):
 		"""position commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_position'):
-			from .Position import Position
-			self._position = Position(self._core, self._cmd_group)
+			from .Position import PositionCls
+			self._position = PositionCls(self._core, self._cmd_group)
 		return self._position
 
-	def clone(self) -> 'PreSelector':
+	def clone(self) -> 'PreSelectorCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = PreSelector(self._core, self._cmd_group.parent)
+		new_group = PreSelectorCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
