@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Theme:
+class ThemeCls:
 	"""Theme commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Theme:
 	def catalog(self):
 		"""catalog commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_catalog'):
-			from .Catalog import Catalog
-			self._catalog = Catalog(self._core, self._cmd_group)
+			from .Catalog import CatalogCls
+			self._catalog = CatalogCls(self._core, self._cmd_group)
 		return self._catalog
 
 	@property
 	def select(self):
 		"""select commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_select'):
-			from .Select import Select
-			self._select = Select(self._core, self._cmd_group)
+			from .Select import SelectCls
+			self._select = SelectCls(self._core, self._cmd_group)
 		return self._select
 
-	def clone(self) -> 'Theme':
+	def clone(self) -> 'ThemeCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Theme(self._core, self._cmd_group.parent)
+		new_group = ThemeCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
