@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -26,6 +26,6 @@ class State:
 		Snippet: value: bool = driver.hardCopy.page.count.state.get() \n
 		This command includes or excludes the page number for printouts consisting of multiple pages (method RsFswp.HardCopy.
 		Content.set) . \n
-			:return: state: No help available"""
+			:return: state: 1 | 0 | ON | OFF 1 | ON The page number is printed. 0 | OFF The page number is not printed."""
 		response = self._core.io.query_str(f'HCOPy:PAGE:COUNt:STATe?')
 		return Conversions.str_to_bool(response)
