@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Left:
+class LeftCls:
 	"""Left commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,7 +16,7 @@ class Left:
 		Snippet: driver.hardCopy.page.margin.left.set(left = 1.0) \n
 		This command defines the margin at the left side of the printout page on which no elements are printed. The margins are
 		defined according to method RsFswp.HardCopy.Page.Margin.Unit.set. \n
-			:param left: 1|2 Printing device.
+			:param left: No help available
 		"""
 		param = Conversions.decimal_value_to_str(left)
 		self._core.io.write(f'HCOPy:PAGE:MARGin:LEFT {param}')
