@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Right:
+class RightCls:
 	"""Right commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,7 +16,7 @@ class Right:
 		Snippet: driver.hardCopy.page.margin.right.set(right = 1.0) \n
 		This command defines the margin at the right side of the printout page on which no elements are printed. The margins are
 		defined according to method RsFswp.HardCopy.Page.Margin.Unit.set. \n
-			:param right: 1|2 Printing device.
+			:param right: No help available
 		"""
 		param = Conversions.decimal_value_to_str(right)
 		self._core.io.write(f'HCOPy:PAGE:MARGin:RIGHt {param}')
