@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Top:
+class TopCls:
 	"""Top commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,7 +16,7 @@ class Top:
 		Snippet: driver.hardCopy.page.margin.top.set(top = 1.0) \n
 		This command defines the margin at the top of the printout page on which no elements are printed. The margins are defined
 		according to method RsFswp.HardCopy.Page.Margin.Unit.set. \n
-			:param top: 1|2 Printing device.
+			:param top: No help available
 		"""
 		param = Conversions.decimal_value_to_str(top)
 		self._core.io.write(f'HCOPy:PAGE:MARGin:TOP {param}')
