@@ -4,7 +4,7 @@ from .....Internal.Utilities import trim_str_response
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class ListPy:
+class ListPyCls:
 	"""ListPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,6 +15,6 @@ class ListPy:
 		"""SCPI: HCOPy:TREPort:ITEM:LIST \n
 		Snippet: value: str = driver.hardCopy.treport.item.listPy.get() \n
 		No command help available \n
-			:return: arg_0: No help available"""
+			:return: channel_type: No help available"""
 		response = self._core.io.query_str(f'HCOPy:TREPort:ITEM:LIST?')
 		return trim_str_response(response)
