@@ -5,20 +5,20 @@ from .... import enums
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class PageSize:
+class PageSizeCls:
 	"""PageSize commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
 		self._cmd_group = CommandsGroup("pageSize", core, parent)
 
-	def set(self, arg_0: enums.HardcopyPageSize) -> None:
+	def set(self, size: enums.HardcopyPageSize) -> None:
 		"""SCPI: HCOPy:TREPort:PAGesize \n
-		Snippet: driver.hardCopy.treport.pageSize.set(arg_0 = enums.HardcopyPageSize.A4) \n
+		Snippet: driver.hardCopy.treport.pageSize.set(size = enums.HardcopyPageSize.A4) \n
 		No command help available \n
-			:param arg_0: No help available
+			:param size: No help available
 		"""
-		param = Conversions.enum_scalar_to_str(arg_0, enums.HardcopyPageSize)
+		param = Conversions.enum_scalar_to_str(size, enums.HardcopyPageSize)
 		self._core.io.write(f'HCOPy:TREPort:PAGesize {param}')
 
 	# noinspection PyTypeChecker
@@ -26,6 +26,6 @@ class PageSize:
 		"""SCPI: HCOPy:TREPort:PAGesize \n
 		Snippet: value: enums.HardcopyPageSize = driver.hardCopy.treport.pageSize.get() \n
 		No command help available \n
-			:return: arg_0: No help available"""
+			:return: size: No help available"""
 		response = self._core.io.query_str(f'HCOPy:TREPort:PAGesize?')
 		return Conversions.str_to_scalar_enum(response, enums.HardcopyPageSize)
