@@ -4,26 +4,26 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
 		self._core = core
 		self._cmd_group = CommandsGroup("state", core, parent)
 
-	def set(self, arg_0: bool) -> None:
+	def set(self, state: bool) -> None:
 		"""SCPI: HCOPy:TREPort:TDSTamp:STATe \n
-		Snippet: driver.hardCopy.treport.tdDtamp.state.set(arg_0 = False) \n
+		Snippet: driver.hardCopy.treport.tdDtamp.state.set(state = False) \n
 		No command help available \n
-			:param arg_0: No help available
+			:param state: No help available
 		"""
-		param = Conversions.bool_to_str(arg_0)
+		param = Conversions.bool_to_str(state)
 		self._core.io.write(f'HCOPy:TREPort:TDSTamp:STATe {param}')
 
 	def get(self) -> bool:
 		"""SCPI: HCOPy:TREPort:TDSTamp:STATe \n
 		Snippet: value: bool = driver.hardCopy.treport.tdDtamp.state.get() \n
 		No command help available \n
-			:return: arg_0: No help available"""
+			:return: state: No help available"""
 		response = self._core.io.query_str(f'HCOPy:TREPort:TDSTamp:STATe?')
 		return Conversions.str_to_bool(response)
