@@ -4,7 +4,7 @@ from ....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Auto:
+class AutoCls:
 	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,8 +14,9 @@ class Auto:
 	def set(self, state: bool) -> None:
 		"""SCPI: INPut:ATTenuation:AUTO \n
 		Snippet: driver.inputPy.attenuation.auto.set(state = False) \n
-		This command turns automatic configuration of the attenuation on and off. \n
-			:param state: ON | 1 Automatically defines the ideal attenuation based on the current signal level. OFF | 0 Allows you to define the attenuation manually with method RsFswp.Applications.K60_Transient.InputPy.Attenuation.set
+		This command couples or decouples the attenuation to the reference level. Thus, when the reference level is changed, the
+		R&S FSWP determines the signal level for optimal internal data processing and sets the required attenuation accordingly. \n
+			:param state: ON | OFF | 0 | 1
 		"""
 		param = Conversions.bool_to_str(state)
 		self._core.io.write(f'INPut:ATTenuation:AUTO {param}')
