@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class File:
+class FileCls:
 	"""File commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class File:
 	def path(self):
 		"""path commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_path'):
-			from .Path import Path
-			self._path = Path(self._core, self._cmd_group)
+			from .Path import PathCls
+			self._path = PathCls(self._core, self._cmd_group)
 		return self._path
 
 	@property
 	def zpading(self):
 		"""zpading commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_zpading'):
-			from .Zpading import Zpading
-			self._zpading = Zpading(self._core, self._cmd_group)
+			from .Zpading import ZpadingCls
+			self._zpading = ZpadingCls(self._core, self._cmd_group)
 		return self._zpading
 
-	def clone(self) -> 'File':
+	def clone(self) -> 'FileCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = File(self._core, self._cmd_group.parent)
+		new_group = FileCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
