@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class State:
 		"""SCPI: INPut:FILTer:YIG[:STATe] \n
 		Snippet: driver.inputPy.filterPy.yig.state.set(state = False) \n
 		Enables or disables the YIG filter. \n
-			:param state: No help available
+			:param state: ON | OFF | 0 | 1
 		"""
 		param = Conversions.bool_to_str(state)
 		self._core.io.write(f'INPut:FILTer:YIG:STATe {param}')
@@ -24,6 +24,6 @@ class State:
 		"""SCPI: INPut:FILTer:YIG[:STATe] \n
 		Snippet: value: bool = driver.inputPy.filterPy.yig.state.get() \n
 		Enables or disables the YIG filter. \n
-			:return: state: No help available"""
+			:return: state: ON | OFF | 0 | 1"""
 		response = self._core.io.query_str(f'INPut:FILTer:YIG:STATe?')
 		return Conversions.str_to_bool(response)
