@@ -4,7 +4,7 @@ from ....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class State:
 		"""SCPI: INPut:GAIN:STATe \n
 		Snippet: driver.inputPy.gain.state.set(state = False) \n
 		This command turns the internal preamplifier on and off. It requires the optional preamplifier hardware.
-		The preamplification value is defined using the INPut<ip>. \n
+		The preamplification value is defined using the method RsFswp.Applications.K30_NoiseFigure.InputPy.Gain.Value.set. \n
 			:param state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on
 		"""
 		param = Conversions.bool_to_str(state)
@@ -25,7 +25,7 @@ class State:
 		"""SCPI: INPut:GAIN:STATe \n
 		Snippet: value: bool = driver.inputPy.gain.state.get() \n
 		This command turns the internal preamplifier on and off. It requires the optional preamplifier hardware.
-		The preamplification value is defined using the INPut<ip>. \n
+		The preamplification value is defined using the method RsFswp.Applications.K30_NoiseFigure.InputPy.Gain.Value.set. \n
 			:return: state: ON | OFF | 0 | 1 OFF | 0 Switches the function off ON | 1 Switches the function on"""
 		response = self._core.io.query_str(f'INPut:GAIN:STATe?')
 		return Conversions.str_to_bool(response)
