@@ -4,7 +4,7 @@ from ....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Value:
+class ValueCls:
 	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Value:
 	def set(self, level: float) -> None:
 		"""SCPI: INPut:GAIN[:VALue] \n
 		Snippet: driver.inputPy.gain.value.set(level = 1.0) \n
-		This command selects the gain if the preamplifier is activated (INP:GAIN:STAT ON, see method RsFswp.Applications.
+		This command selects the 'gain' if the preamplifier is activated (INP:GAIN:STAT ON, see method RsFswp.Applications.
 		K30_NoiseFigure.InputPy.Gain.State.set) . The command requires the additional preamplifier hardware option. \n
 			:param level: No help available
 		"""
@@ -24,7 +24,7 @@ class Value:
 	def get(self) -> float:
 		"""SCPI: INPut:GAIN[:VALue] \n
 		Snippet: value: float = driver.inputPy.gain.value.get() \n
-		This command selects the gain if the preamplifier is activated (INP:GAIN:STAT ON, see method RsFswp.Applications.
+		This command selects the 'gain' if the preamplifier is activated (INP:GAIN:STAT ON, see method RsFswp.Applications.
 		K30_NoiseFigure.InputPy.Gain.State.set) . The command requires the additional preamplifier hardware option. \n
 			:return: level: No help available"""
 		response = self._core.io.query_str(f'INPut:GAIN:VALue?')
