@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Loscillator:
+class LoscillatorCls:
 	"""Loscillator commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Loscillator:
 	def source(self):
 		"""source commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_source'):
-			from .Source import Source
-			self._source = Source(self._core, self._cmd_group)
+			from .Source import SourceCls
+			self._source = SourceCls(self._core, self._cmd_group)
 		return self._source
 
-	def clone(self) -> 'Loscillator':
+	def clone(self) -> 'LoscillatorCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Loscillator(self._core, self._cmd_group.parent)
+		new_group = LoscillatorCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
