@@ -6,7 +6,7 @@ from ... import repcap
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Select:
+class SelectCls:
 	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -18,7 +18,7 @@ class Select:
 		Snippet: driver.inputPy.select.set(source = enums.InputSource.ABBand, inputIx = repcap.InputIx.Default) \n
 		This command selects the signal source for measurements, i.e. it defines which connector is used to input data to the R&S
 		FSWP. \n
-			:param source: RF Radio Frequency ('RF INPUT' connector) FIQ I/Q data file (selected by method RsFswp.InputPy.File.Path.set) For details see 'Basics on Input from I/Q Data Files'.
+			:param source: RF Radio Frequency ('RF INPUT' connector) FIQ I/Q data file (selected by method RsFswp.InputPy.File.Path.set) For details, see 'Basics on input from I/Q data files'.
 			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
 		"""
 		param = Conversions.enum_scalar_to_str(source, enums.InputSource)
