@@ -5,7 +5,7 @@ from ... import enums
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Select:
+class SelectCls:
 	"""Select commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -19,7 +19,7 @@ class Select:
 		name. Also see
 			INTRO_CMD_HELP: See also \n
 			- method RsFswp.Instrument.Create.New.set
-			- 'Programming Example: Performing a Sequence of Measurements' \n
+			- 'Programming example: performing a sequence of measurements' \n
 			:param channel_type: (enum or string) Channel type of the new channel. For a list of available channel types see method RsFswp.Instrument.ListPy.get_.
 		"""
 		param = Conversions.enum_ext_scalar_to_str(channel_type, enums.ChannelType)
