@@ -4,7 +4,7 @@ from ...Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class SelectName:
+class SelectNameCls:
 	"""SelectName commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -18,7 +18,7 @@ class SelectName:
 		name. Also see
 			INTRO_CMD_HELP: See also \n
 			- method RsFswp.Instrument.Create.New.set
-			- 'Programming Example: Performing a Sequence of Measurements' \n
+			- 'Programming example: performing a sequence of measurements' \n
 			:param channel_name: String containing the name of the channel.
 		"""
 		param = Conversions.value_to_quoted_str(channel_name)
