@@ -6,7 +6,7 @@ from ....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class UnusedDrives:
+class UnusedDrivesCls:
 	"""UnusedDrives commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
