@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Lines:
+class LinesCls:
 	"""Lines commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Lines:
 	def active(self):
 		"""active commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_active'):
-			from .Active import Active
-			self._active = Active(self._core, self._cmd_group)
+			from .Active import ActiveCls
+			self._active = ActiveCls(self._core, self._cmd_group)
 		return self._active
 
 	@property
 	def all(self):
 		"""all commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_all'):
-			from .All import All
-			self._all = All(self._core, self._cmd_group)
+			from .All import AllCls
+			self._all = AllCls(self._core, self._cmd_group)
 		return self._all
 
-	def clone(self) -> 'Lines':
+	def clone(self) -> 'LinesCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Lines(self._core, self._cmd_group.parent)
+		new_group = LinesCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
