@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Trace:
+class TraceCls:
 	"""Trace commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Trace:
 	def active(self):
 		"""active commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_active'):
-			from .Active import Active
-			self._active = Active(self._core, self._cmd_group)
+			from .Active import ActiveCls
+			self._active = ActiveCls(self._core, self._cmd_group)
 		return self._active
 
-	def clone(self) -> 'Trace':
+	def clone(self) -> 'TraceCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Trace(self._core, self._cmd_group.parent)
+		new_group = TraceCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
