@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class State:
+class StateCls:
 	"""State commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,8 +15,8 @@ class State:
 	def next(self):
 		"""next commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_next'):
-			from .Next import Next
-			self._next = Next(self._core, self._cmd_group)
+			from .Next import NextCls
+			self._next = NextCls(self._core, self._cmd_group)
 		return self._next
 
 	def set(self, filename: str) -> None:
@@ -28,10 +28,10 @@ class State:
 		param = Conversions.value_to_quoted_str(filename)
 		self._core.io.write_with_opc(f'MMEMory:STORe:STATe 1, {param}')
 
-	def clone(self) -> 'State':
+	def clone(self) -> 'StateCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = State(self._core, self._cmd_group.parent)
+		new_group = StateCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
