@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Af:
+class AfCls:
 	"""Af commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Af:
 	def cfrequency(self):
 		"""cfrequency commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_cfrequency'):
-			from .Cfrequency import Cfrequency
-			self._cfrequency = Cfrequency(self._core, self._cmd_group)
+			from .Cfrequency import CfrequencyCls
+			self._cfrequency = CfrequencyCls(self._core, self._cmd_group)
 		return self._cfrequency
 
-	def clone(self) -> 'Af':
+	def clone(self) -> 'AfCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Af(self._core, self._cmd_group.parent)
+		new_group = AfCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
