@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Online:
+class OnlineCls:
 	"""Online commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Online:
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def source(self):
 		"""source commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_source'):
-			from .Source import Source
-			self._source = Source(self._core, self._cmd_group)
+			from .Source import SourceCls
+			self._source = SourceCls(self._core, self._cmd_group)
 		return self._source
 
 	@property
 	def af(self):
 		"""af commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_af'):
-			from .Af import Af
-			self._af = Af(self._core, self._cmd_group)
+			from .Af import AfCls
+			self._af = AfCls(self._core, self._cmd_group)
 		return self._af
 
-	def clone(self) -> 'Online':
+	def clone(self) -> 'OnlineCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Online(self._core, self._cmd_group.parent)
+		new_group = OnlineCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
