@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ademod:
+class AdemodCls:
 	"""Ademod commands group definition. 3 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Ademod:
 	def online(self):
 		"""online commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_online'):
-			from .Online import Online
-			self._online = Online(self._core, self._cmd_group)
+			from .Online import OnlineCls
+			self._online = OnlineCls(self._core, self._cmd_group)
 		return self._online
 
-	def clone(self) -> 'Ademod':
+	def clone(self) -> 'AdemodCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ademod(self._core, self._cmd_group.parent)
+		new_group = AdemodCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
