@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Ifreq:
+class IfreqCls:
 	"""Ifreq commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Ifreq:
 	def source(self):
 		"""source commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_source'):
-			from .Source import Source
-			self._source = Source(self._core, self._cmd_group)
+			from .Source import SourceCls
+			self._source = SourceCls(self._core, self._cmd_group)
 		return self._source
 
 	@property
 	def ifFrequency(self):
 		"""ifFrequency commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ifFrequency'):
-			from .IfFrequency import IfFrequency
-			self._ifFrequency = IfFrequency(self._core, self._cmd_group)
+			from .IfFrequency import IfFrequencyCls
+			self._ifFrequency = IfFrequencyCls(self._core, self._cmd_group)
 		return self._ifFrequency
 
-	def clone(self) -> 'Ifreq':
+	def clone(self) -> 'IfreqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Ifreq(self._core, self._cmd_group.parent)
+		new_group = IfreqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
