@@ -5,7 +5,7 @@ from ..... import enums
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Offset:
+class OffsetCls:
 	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,7 +16,7 @@ class Offset:
 		"""SCPI: [SENSe]:ADEMod:FM:OFFSet \n
 		Snippet: driver.sense.ademod.fm.offset.set(result_type = enums.ResultTypeC.AVERage) \n
 		No command help available \n
-			:param result_type: IMMediate | AVERage
+			:param result_type: No help available
 		"""
 		param = Conversions.enum_scalar_to_str(result_type, enums.ResultTypeC)
 		self._core.io.write(f'SENSe:ADEMod:FM:OFFSet {param}')
@@ -26,6 +26,6 @@ class Offset:
 		"""SCPI: [SENSe]:ADEMod:FM:OFFSet \n
 		Snippet: value: enums.ResultTypeC = driver.sense.ademod.fm.offset.get() \n
 		No command help available \n
-			:return: result_type: IMMediate | AVERage"""
+			:return: result_type: No help available"""
 		response = self._core.io.query_str(f'SENSe:ADEMod:FM:OFFSet?')
 		return Conversions.str_to_scalar_enum(response, enums.ResultTypeC)
