@@ -4,7 +4,7 @@ from ....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mtime:
+class MtimeCls:
 	"""Mtime commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Mtime:
 	def set(self, time: float) -> None:
 		"""SCPI: [SENSe]:ADEMod:MTIMe \n
 		Snippet: driver.sense.ademod.mtime.set(time = 1.0) \n
-		This command defines the measurement time for analog demodulation. \n
+		This command defines the measurement time for Analog Modulation Analysis. \n
 			:param time: Unit: S
 		"""
 		param = Conversions.decimal_value_to_str(time)
@@ -23,7 +23,7 @@ class Mtime:
 	def get(self) -> float:
 		"""SCPI: [SENSe]:ADEMod:MTIMe \n
 		Snippet: value: float = driver.sense.ademod.mtime.get() \n
-		This command defines the measurement time for analog demodulation. \n
+		This command defines the measurement time for Analog Modulation Analysis. \n
 			:return: time: Unit: S"""
 		response = self._core.io.query_str(f'SENSe:ADEMod:MTIMe?')
 		return Conversions.str_to_float(response)
