@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Span:
+class SpanCls:
 	"""Span commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Span:
 	def maximum(self):
 		"""maximum commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_maximum'):
-			from .Maximum import Maximum
-			self._maximum = Maximum(self._core, self._cmd_group)
+			from .Maximum import MaximumCls
+			self._maximum = MaximumCls(self._core, self._cmd_group)
 		return self._maximum
 
 	@property
 	def zoom(self):
 		"""zoom commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_zoom'):
-			from .Zoom import Zoom
-			self._zoom = Zoom(self._core, self._cmd_group)
+			from .Zoom import ZoomCls
+			self._zoom = ZoomCls(self._core, self._cmd_group)
 		return self._zoom
 
-	def clone(self) -> 'Span':
+	def clone(self) -> 'SpanCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Span(self._core, self._cmd_group.parent)
+		new_group = SpanCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
