@@ -5,7 +5,7 @@ from ...... import enums
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Mode:
+class ModeCls:
 	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,9 +15,8 @@ class Mode:
 	def set(self, mode: enums.AutoManualMode) -> None:
 		"""SCPI: [SENSe]:ADJust:CONFigure:DURation:MODE \n
 		Snippet: driver.sense.adjust.configure.duration.mode.set(mode = enums.AutoManualMode.AUTO) \n
-		In order to determine the ideal reference level, the R&S FSWP performs a measurement on the current input data.
-		This command selects the way the R&S FSWP determines the length of the measurement . \n
-			:param mode: AUTO The R&S FSWP determines the measurement length automatically according to the current input data. MANual The R&S FSWP uses the measurement length defined by CONFigure:DURation.
+		No command help available \n
+			:param mode: No help available
 		"""
 		param = Conversions.enum_scalar_to_str(mode, enums.AutoManualMode)
 		self._core.io.write(f'SENSe:ADJust:CONFigure:DURation:MODE {param}')
@@ -26,8 +25,7 @@ class Mode:
 	def get(self) -> enums.AutoManualMode:
 		"""SCPI: [SENSe]:ADJust:CONFigure:DURation:MODE \n
 		Snippet: value: enums.AutoManualMode = driver.sense.adjust.configure.duration.mode.get() \n
-		In order to determine the ideal reference level, the R&S FSWP performs a measurement on the current input data.
-		This command selects the way the R&S FSWP determines the length of the measurement . \n
-			:return: mode: AUTO The R&S FSWP determines the measurement length automatically according to the current input data. MANual The R&S FSWP uses the measurement length defined by CONFigure:DURation."""
+		No command help available \n
+			:return: mode: No help available"""
 		response = self._core.io.query_str(f'SENSe:ADJust:CONFigure:DURation:MODE?')
 		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)
