@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Frequency:
+class FrequencyCls:
 	"""Frequency commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Frequency:
 	def limit(self):
 		"""limit commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_limit'):
-			from .Limit import Limit
-			self._limit = Limit(self._core, self._cmd_group)
+			from .Limit import LimitCls
+			self._limit = LimitCls(self._core, self._cmd_group)
 		return self._limit
 
-	def clone(self) -> 'Frequency':
+	def clone(self) -> 'FrequencyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Frequency(self._core, self._cmd_group.parent)
+		new_group = FrequencyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
