@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Hysteresis:
+class HysteresisCls:
 	"""Hysteresis commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Hysteresis:
 	def lower(self):
 		"""lower commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_lower'):
-			from .Lower import Lower
-			self._lower = Lower(self._core, self._cmd_group)
+			from .Lower import LowerCls
+			self._lower = LowerCls(self._core, self._cmd_group)
 		return self._lower
 
 	@property
 	def upper(self):
 		"""upper commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_upper'):
-			from .Upper import Upper
-			self._upper = Upper(self._core, self._cmd_group)
+			from .Upper import UpperCls
+			self._upper = UpperCls(self._core, self._cmd_group)
 		return self._upper
 
-	def clone(self) -> 'Hysteresis':
+	def clone(self) -> 'HysteresisCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Hysteresis(self._core, self._cmd_group.parent)
+		new_group = HysteresisCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
