@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Level:
+class LevelCls:
 	"""Level commands group definition. 3 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Level:
 	def threshold(self):
 		"""threshold commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_threshold'):
-			from .Threshold import Threshold
-			self._threshold = Threshold(self._core, self._cmd_group)
+			from .Threshold import ThresholdCls
+			self._threshold = ThresholdCls(self._core, self._cmd_group)
 		return self._threshold
 
 	@property
 	def duration(self):
 		"""duration commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_duration'):
-			from .Duration import Duration
-			self._duration = Duration(self._core, self._cmd_group)
+			from .Duration import DurationCls
+			self._duration = DurationCls(self._core, self._cmd_group)
 		return self._duration
 
-	def clone(self) -> 'Level':
+	def clone(self) -> 'LevelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Level(self._core, self._cmd_group.parent)
+		new_group = LevelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
