@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Level:
+class LevelCls:
 	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -13,9 +13,8 @@ class Level:
 	def set(self, opc_timeout_ms: int = -1) -> None:
 		"""SCPI: [SENSe]:ADJust:LEVel \n
 		Snippet: driver.sense.adjust.level.set() \n
-		This command initiates a single (internal) measurement that evaluates and sets the ideal reference level for the current
-		input data and measurement settings. This ensures that the settings of the RF attenuation and the reference level are
-		optimally adjusted to the signal level without overloading the R&S FSWP or limiting the dynamic range by an S/N ratio
-		that is too small. \n
+		Initiates a single (internal) measurement that evaluates and sets the ideal reference level for the current input data
+		and measurement settings. Thus, the settings of the RF attenuation and the reference level are optimized for the signal
+		level. The R&S FSWP is not overloaded and the dynamic range is not limited by an S/N ratio that is too small. \n
 			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
 		self._core.io.write_with_opc(f'SENSe:ADJust:LEVel', opc_timeout_ms)
