@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Auto:
+class AutoCls:
 	"""Auto commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Auto:
 	def continuous(self):
 		"""continuous commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_continuous'):
-			from .Continuous import Continuous
-			self._continuous = Continuous(self._core, self._cmd_group)
+			from .Continuous import ContinuousCls
+			self._continuous = ContinuousCls(self._core, self._cmd_group)
 		return self._continuous
 
-	def clone(self) -> 'Auto':
+	def clone(self) -> 'AutoCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Auto(self._core, self._cmd_group.parent)
+		new_group = AutoCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
