@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Average:
+class AverageCls:
 	"""Average commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Average:
 	def count(self):
 		"""count commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_count'):
-			from .Count import Count
-			self._count = Count(self._core, self._cmd_group)
+			from .Count import CountCls
+			self._count = CountCls(self._core, self._cmd_group)
 		return self._count
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
 	@property
 	def typePy(self):
 		"""typePy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_typePy'):
-			from .TypePy import TypePy
-			self._typePy = TypePy(self._core, self._cmd_group)
+			from .TypePy import TypePyCls
+			self._typePy = TypePyCls(self._core, self._cmd_group)
 		return self._typePy
 
-	def clone(self) -> 'Average':
+	def clone(self) -> 'AverageCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Average(self._core, self._cmd_group.parent)
+		new_group = AverageCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
