@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Baseband:
+class BasebandCls:
 	"""Baseband commands group definition. 24 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Baseband:
 	def user(self):
 		"""user commands group. 6 Sub-classes, 2 commands."""
 		if not hasattr(self, '_user'):
-			from .User import User
-			self._user = User(self._core, self._cmd_group)
+			from .User import UserCls
+			self._user = UserCls(self._core, self._cmd_group)
 		return self._user
 
-	def clone(self) -> 'Baseband':
+	def clone(self) -> 'BasebandCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Baseband(self._core, self._cmd_group.parent)
+		new_group = BasebandCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
