@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Preset:
+class PresetCls:
 	"""Preset commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Preset:
 	def standard(self):
 		"""standard commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_standard'):
-			from .Standard import Standard
-			self._standard = Standard(self._core, self._cmd_group)
+			from .Standard import StandardCls
+			self._standard = StandardCls(self._core, self._cmd_group)
 		return self._standard
 
 	@property
 	def restore(self):
 		"""restore commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_restore'):
-			from .Restore import Restore
-			self._restore = Restore(self._core, self._cmd_group)
+			from .Restore import RestoreCls
+			self._restore = RestoreCls(self._core, self._cmd_group)
 		return self._restore
 
 	@property
 	def store(self):
 		"""store commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_store'):
-			from .Store import Store
-			self._store = Store(self._core, self._cmd_group)
+			from .Store import StoreCls
+			self._store = StoreCls(self._core, self._cmd_group)
 		return self._store
 
-	def clone(self) -> 'Preset':
+	def clone(self) -> 'PresetCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Preset(self._core, self._cmd_group.parent)
+		new_group = PresetCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
