@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class InputPy:
+class InputPyCls:
 	"""InputPy commands group definition. 4 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class InputPy:
 	def attenuation(self):
 		"""attenuation commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_attenuation'):
-			from .Attenuation import Attenuation
-			self._attenuation = Attenuation(self._core, self._cmd_group)
+			from .Attenuation import AttenuationCls
+			self._attenuation = AttenuationCls(self._core, self._cmd_group)
 		return self._attenuation
 
 	@property
 	def gain(self):
 		"""gain commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_gain'):
-			from .Gain import Gain
-			self._gain = Gain(self._core, self._cmd_group)
+			from .Gain import GainCls
+			self._gain = GainCls(self._core, self._cmd_group)
 		return self._gain
 
-	def clone(self) -> 'InputPy':
+	def clone(self) -> 'InputPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = InputPy(self._core, self._cmd_group.parent)
+		new_group = InputPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
