@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iq:
+class IqCls:
 	"""Iq commands group definition. 2 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Iq:
 	def bandwidth(self):
 		"""bandwidth commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_bandwidth'):
-			from .Bandwidth import Bandwidth
-			self._bandwidth = Bandwidth(self._core, self._cmd_group)
+			from .Bandwidth import BandwidthCls
+			self._bandwidth = BandwidthCls(self._core, self._cmd_group)
 		return self._bandwidth
 
-	def clone(self) -> 'Iq':
+	def clone(self) -> 'IqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iq(self._core, self._cmd_group.parent)
+		new_group = IqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
