@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class ListPy:
+class ListPyCls:
 	"""ListPy commands group definition. 26 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class ListPy:
 	def xadjust(self):
 		"""xadjust commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_xadjust'):
-			from .Xadjust import Xadjust
-			self._xadjust = Xadjust(self._core, self._cmd_group)
+			from .Xadjust import XadjustCls
+			self._xadjust = XadjustCls(self._core, self._cmd_group)
 		return self._xadjust
 
 	@property
 	def power(self):
 		"""power commands group. 4 Sub-classes, 0 commands."""
 		if not hasattr(self, '_power'):
-			from .Power import Power
-			self._power = Power(self._core, self._cmd_group)
+			from .Power import PowerCls
+			self._power = PowerCls(self._core, self._cmd_group)
 		return self._power
 
 	@property
 	def range(self):
 		"""range commands group. 12 Sub-classes, 1 commands."""
 		if not hasattr(self, '_range'):
-			from .Range import Range
-			self._range = Range(self._core, self._cmd_group)
+			from .Range import RangeCls
+			self._range = RangeCls(self._core, self._cmd_group)
 		return self._range
 
-	def clone(self) -> 'ListPy':
+	def clone(self) -> 'ListPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = ListPy(self._core, self._cmd_group.parent)
+		new_group = ListPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
