@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Loss:
+class LossCls:
 	"""Loss commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Loss:
 	def high(self):
 		"""high commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_high'):
-			from .High import High
-			self._high = High(self._core, self._cmd_group)
+			from .High import HighCls
+			self._high = HighCls(self._core, self._cmd_group)
 		return self._high
 
 	@property
 	def low(self):
 		"""low commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_low'):
-			from .Low import Low
-			self._low = Low(self._core, self._cmd_group)
+			from .Low import LowCls
+			self._low = LowCls(self._core, self._cmd_group)
 		return self._low
 
 	@property
 	def table(self):
 		"""table commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_table'):
-			from .Table import Table
-			self._table = Table(self._core, self._cmd_group)
+			from .Table import TableCls
+			self._table = TableCls(self._core, self._cmd_group)
 		return self._table
 
-	def clone(self) -> 'Loss':
+	def clone(self) -> 'LossCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Loss(self._core, self._cmd_group.parent)
+		new_group = LossCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
