@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Result:
+class ResultCls:
 	"""Result commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Result:
 	def listPy(self):
 		"""listPy commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_listPy'):
-			from .ListPy import ListPy
-			self._listPy = ListPy(self._core, self._cmd_group)
+			from .ListPy import ListPyCls
+			self._listPy = ListPyCls(self._core, self._cmd_group)
 		return self._listPy
 
 	@property
 	def min(self):
 		"""min commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_min'):
-			from .Min import Min
-			self._min = Min(self._core, self._cmd_group)
+			from .Min import MinCls
+			self._min = MinCls(self._core, self._cmd_group)
 		return self._min
 
-	def clone(self) -> 'Result':
+	def clone(self) -> 'ResultCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Result(self._core, self._cmd_group.parent)
+		new_group = ResultCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
