@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Technology:
+class TechnologyCls:
 	"""Technology commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Technology:
 	def channel(self):
 		"""channel commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_channel'):
-			from .Channel import Channel
-			self._channel = Channel(self._core, self._cmd_group)
+			from .Channel import ChannelCls
+			self._channel = ChannelCls(self._core, self._cmd_group)
 		return self._channel
 
-	def clone(self) -> 'Technology':
+	def clone(self) -> 'TechnologyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Technology(self._core, self._cmd_group.parent)
+		new_group = TechnologyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
