@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iq:
+class IqCls:
 	"""Iq commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Iq:
 	def sync(self):
 		"""sync commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_sync'):
-			from .Sync import Sync
-			self._sync = Sync(self._core, self._cmd_group)
+			from .Sync import SyncCls
+			self._sync = SyncCls(self._core, self._cmd_group)
 		return self._sync
 
-	def clone(self) -> 'Iq':
+	def clone(self) -> 'IqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iq(self._core, self._cmd_group.parent)
+		new_group = IqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
