@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Channel:
+class ChannelCls:
 	"""Channel commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Channel:
 	def coupling(self):
 		"""coupling commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_coupling'):
-			from .Coupling import Coupling
-			self._coupling = Coupling(self._core, self._cmd_group)
+			from .Coupling import CouplingCls
+			self._coupling = CouplingCls(self._core, self._cmd_group)
 		return self._coupling
 
-	def clone(self) -> 'Channel':
+	def clone(self) -> 'ChannelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Channel(self._core, self._cmd_group.parent)
+		new_group = ChannelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
