@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Trigger:
+class TriggerCls:
 	"""Trigger commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Trigger:
 	def output(self):
 		"""output commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_output'):
-			from .Output import Output
-			self._output = Output(self._core, self._cmd_group)
+			from .Output import OutputCls
+			self._output = OutputCls(self._core, self._cmd_group)
 		return self._output
 
-	def clone(self) -> 'Trigger':
+	def clone(self) -> 'TriggerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Trigger(self._core, self._cmd_group.parent)
+		new_group = TriggerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
