@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Pulse:
+class PulseCls:
 	"""Pulse commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Pulse:
 	def trigger(self):
 		"""trigger commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_trigger'):
-			from .Trigger import Trigger
-			self._trigger = Trigger(self._core, self._cmd_group)
+			from .Trigger import TriggerCls
+			self._trigger = TriggerCls(self._core, self._cmd_group)
 		return self._trigger
 
 	@property
 	def period(self):
 		"""period commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_period'):
-			from .Period import Period
-			self._period = Period(self._core, self._cmd_group)
+			from .Period import PeriodCls
+			self._period = PeriodCls(self._core, self._cmd_group)
 		return self._period
 
 	@property
 	def width(self):
 		"""width commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_width'):
-			from .Width import Width
-			self._width = Width(self._core, self._cmd_group)
+			from .Width import WidthCls
+			self._width = WidthCls(self._core, self._cmd_group)
 		return self._width
 
-	def clone(self) -> 'Pulse':
+	def clone(self) -> 'PulseCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Pulse(self._core, self._cmd_group.parent)
+		new_group = PulseCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
