@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Level:
+class LevelCls:
 	"""Level commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Level:
 	def amplitude(self):
 		"""amplitude commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_amplitude'):
-			from .Amplitude import Amplitude
-			self._amplitude = Amplitude(self._core, self._cmd_group)
+			from .Amplitude import AmplitudeCls
+			self._amplitude = AmplitudeCls(self._core, self._cmd_group)
 		return self._amplitude
 
 	@property
 	def limit(self):
 		"""limit commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_limit'):
-			from .Limit import Limit
-			self._limit = Limit(self._core, self._cmd_group)
+			from .Limit import LimitCls
+			self._limit = LimitCls(self._core, self._cmd_group)
 		return self._limit
 
 	@property
 	def state(self):
 		"""state commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_state'):
-			from .State import State
-			self._state = State(self._core, self._cmd_group)
+			from .State import StateCls
+			self._state = StateCls(self._core, self._cmd_group)
 		return self._state
 
-	def clone(self) -> 'Level':
+	def clone(self) -> 'LevelCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Level(self._core, self._cmd_group.parent)
+		new_group = LevelCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
