@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Queue:
+class QueueCls:
 	"""Queue commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Queue:
 	def next(self):
 		"""next commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_next'):
-			from .Next import Next
-			self._next = Next(self._core, self._cmd_group)
+			from .Next import NextCls
+			self._next = NextCls(self._core, self._cmd_group)
 		return self._next
 
-	def clone(self) -> 'Queue':
+	def clone(self) -> 'QueueCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Queue(self._core, self._cmd_group.parent)
+		new_group = QueueCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
