@@ -3,7 +3,7 @@ from .......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Alignment:
+class AlignmentCls:
 	"""Alignment commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Alignment:
 	def date(self):
 		"""date commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_date'):
-			from .Date import Date
-			self._date = Date(self._core, self._cmd_group)
+			from .Date import DateCls
+			self._date = DateCls(self._core, self._cmd_group)
 		return self._date
 
 	@property
 	def step(self):
 		"""step commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_step'):
-			from .Step import Step
-			self._step = Step(self._core, self._cmd_group)
+			from .Step import StepCls
+			self._step = StepCls(self._core, self._cmd_group)
 		return self._step
 
-	def clone(self) -> 'Alignment':
+	def clone(self) -> 'AlignmentCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Alignment(self._core, self._cmd_group.parent)
+		new_group = AlignmentCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
