@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rest:
+class RestCls:
 	"""Rest commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Rest:
 	def enable(self):
 		"""enable commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_enable'):
-			from .Enable import Enable
-			self._enable = Enable(self._core, self._cmd_group)
+			from .Enable import EnableCls
+			self._enable = EnableCls(self._core, self._cmd_group)
 		return self._enable
 
-	def clone(self) -> 'Rest':
+	def clone(self) -> 'RestCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rest(self._core, self._cmd_group.parent)
+		new_group = RestCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
