@@ -4,7 +4,7 @@ from ......Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rw:
+class RwCls:
 	"""Rw commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,7 +14,7 @@ class Rw:
 	def set(self, community: str) -> None:
 		"""SCPI: SYSTem:COMMunicate:SNMP:COMMunity:RW \n
 		Snippet: driver.system.communicate.snmp.community.rw.set(community = '1') \n
-		This command sets the SNMP community string for read-write access.
+		Defines the SNMP community string for read-write access.
 			INTRO_CMD_HELP: Prerequisites for this command: \n
 			- Select an SNMP version that supports communities (method RsFswp.System.Communicate.Snmp.Version.set) . \n
 			:param community: String containing the community name.
