@@ -5,7 +5,7 @@ from .......Internal.ArgStruct import ArgStruct
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class All:
+class AllCls:
 	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -29,7 +29,7 @@ class All:
 	def get(self) -> GetStruct:
 		"""SCPI: SYSTem:COMMunicate:SNMP:USM:USER:ALL \n
 		Snippet: value: GetStruct = driver.system.communicate.snmp.usm.user.all.get() \n
-		This command returns the number of users and a list of all SNMP users for SNMPv3.
+		Queries the number of users and a list of all SNMP users for SNMPv3.
 			INTRO_CMD_HELP: Prerequisites for this command: \n
 			- Select SNMPv3 (method RsFswp.System.Communicate.Snmp.Version.set) . \n
 			:return: structure: for return value, see the help for GetStruct structure arguments."""
