@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Usm:
+class UsmCls:
 	"""Usm commands group definition. 4 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Usm:
 	def user(self):
 		"""user commands group. 1 Sub-classes, 3 commands."""
 		if not hasattr(self, '_user'):
-			from .User import User
-			self._user = User(self._core, self._cmd_group)
+			from .User import UserCls
+			self._user = UserCls(self._core, self._cmd_group)
 		return self._user
 
-	def clone(self) -> 'Usm':
+	def clone(self) -> 'UsmCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Usm(self._core, self._cmd_group.parent)
+		new_group = UsmCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
