@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rdevice:
+class RdeviceCls:
 	"""Rdevice commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Rdevice:
 	def generator(self):
 		"""generator commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_generator'):
-			from .Generator import Generator
-			self._generator = Generator(self._core, self._cmd_group)
+			from .Generator import GeneratorCls
+			self._generator = GeneratorCls(self._core, self._cmd_group)
 		return self._generator
 
-	def clone(self) -> 'Rdevice':
+	def clone(self) -> 'RdeviceCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Rdevice(self._core, self._cmd_group.parent)
+		new_group = RdeviceCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
