@@ -4,7 +4,7 @@ from ...Internal.Utilities import trim_str_response
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class DeviceFootprint:
+class DeviceFootprintCls:
 	"""DeviceFootprint commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
