@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Clear:
+class ClearCls:
 	"""Clear commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Clear:
 	def remote(self):
 		"""remote commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_remote'):
-			from .Remote import Remote
-			self._remote = Remote(self._core, self._cmd_group)
+			from .Remote import RemoteCls
+			self._remote = RemoteCls(self._core, self._cmd_group)
 		return self._remote
 
-	def clone(self) -> 'Clear':
+	def clone(self) -> 'ClearCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Clear(self._core, self._cmd_group.parent)
+		new_group = ClearCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
