@@ -4,7 +4,7 @@ from ....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Display:
+class DisplayCls:
 	"""Display commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,8 +14,8 @@ class Display:
 	def set(self, state: bool) -> None:
 		"""SCPI: SYSTem:ERRor:DISPlay \n
 		Snippet: driver.system.error.display.set(state = False) \n
-		This command the error display during remote operation on and off. If activated, the R&S FSWP displays a message box at
-		the bottom of the screen that contains the most recent type of error and the command that caused the error. \n
+		This command switches the error display during remote operation on and off. If activated, the R&S FSWP displays a message
+		box at the bottom of the screen that contains the most recent type of error and the command that caused the error. \n
 			:param state: ON | OFF | 1 | 0
 		"""
 		param = Conversions.bool_to_str(state)
@@ -24,8 +24,8 @@ class Display:
 	def get(self) -> bool:
 		"""SCPI: SYSTem:ERRor:DISPlay \n
 		Snippet: value: bool = driver.system.error.display.get() \n
-		This command the error display during remote operation on and off. If activated, the R&S FSWP displays a message box at
-		the bottom of the screen that contains the most recent type of error and the command that caused the error. \n
+		This command switches the error display during remote operation on and off. If activated, the R&S FSWP displays a message
+		box at the bottom of the screen that contains the most recent type of error and the command that caused the error. \n
 			:return: state: ON | OFF | 1 | 0"""
 		response = self._core.io.query_str(f'SYSTem:ERRor:DISPlay?')
 		return Conversions.str_to_bool(response)
