@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class FormatPy:
+class FormatPyCls:
 	"""FormatPy commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class FormatPy:
 	def ident(self):
 		"""ident commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_ident'):
-			from .Ident import Ident
-			self._ident = Ident(self._core, self._cmd_group)
+			from .Ident import IdentCls
+			self._ident = IdentCls(self._core, self._cmd_group)
 		return self._ident
 
-	def clone(self) -> 'FormatPy':
+	def clone(self) -> 'FormatPyCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = FormatPy(self._core, self._cmd_group.parent)
+		new_group = FormatPyCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
