@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Syntax:
+class SyntaxCls:
 	"""Syntax commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,8 +15,8 @@ class Syntax:
 	def all(self):
 		"""all commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_all'):
-			from .All import All
-			self._all = All(self._core, self._cmd_group)
+			from .All import AllCls
+			self._all = AllCls(self._core, self._cmd_group)
 		return self._all
 
 	def get(self, command: str) -> bytes:
@@ -29,10 +29,10 @@ class Syntax:
 		response = self._core.io.query_bin_block_ERROR(f'SYSTem:HELP:SYNTax? {param}')
 		return response
 
-	def clone(self) -> 'Syntax':
+	def clone(self) -> 'SyntaxCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Syntax(self._core, self._cmd_group.parent)
+		new_group = SyntaxCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
