@@ -5,7 +5,7 @@ from ...Internal.Utilities import trim_str_response
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Language:
+class LanguageCls:
 	"""Language commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -16,7 +16,7 @@ class Language:
 		"""SCPI: SYSTem:LANGuage \n
 		Snippet: driver.system.language.set(language = '1') \n
 		This command selects the system language. \n
-			:param language: String containing the name of the language. 'SCPI' SCPI language. 'PSA' PSA emulation. For a list of supported commands, see 'Reference: Command Set of Emulated PSA Models'.
+			:param language: String containing the name of the language. 'SCPI' SCPI language. 'PSA' PSA emulation. For a list of supported commands, see 'Reference: command set of emulated PSA models'.
 		"""
 		param = Conversions.value_to_quoted_str(language)
 		self._core.io.write(f'SYSTem:LANGuage {param}')
@@ -25,6 +25,6 @@ class Language:
 		"""SCPI: SYSTem:LANGuage \n
 		Snippet: value: str = driver.system.language.get() \n
 		This command selects the system language. \n
-			:return: language: String containing the name of the language. 'SCPI' SCPI language. 'PSA' PSA emulation. For a list of supported commands, see 'Reference: Command Set of Emulated PSA Models'."""
+			:return: language: String containing the name of the language. 'SCPI' SCPI language. 'PSA' PSA emulation. For a list of supported commands, see 'Reference: command set of emulated PSA models'."""
 		response = self._core.io.query_str(f'SYSTem:LANGuage?')
 		return trim_str_response(response)
