@@ -3,7 +3,7 @@ from ......Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Tstamp:
+class TstampCls:
 	"""Tstamp commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,22 +14,22 @@ class Tstamp:
 	def sstart(self):
 		"""sstart commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_sstart'):
-			from .Sstart import Sstart
-			self._sstart = Sstart(self._core, self._cmd_group)
+			from .Sstart import SstartCls
+			self._sstart = SstartCls(self._core, self._cmd_group)
 		return self._sstart
 
 	@property
 	def trigger(self):
 		"""trigger commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_trigger'):
-			from .Trigger import Trigger
-			self._trigger = Trigger(self._core, self._cmd_group)
+			from .Trigger import TriggerCls
+			self._trigger = TriggerCls(self._core, self._cmd_group)
 		return self._trigger
 
-	def clone(self) -> 'Tstamp':
+	def clone(self) -> 'TstampCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Tstamp(self._core, self._cmd_group.parent)
+		new_group = TstampCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
