@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Iq:
+class IqCls:
 	"""Iq commands group definition. 6 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Iq:
 	def data(self):
 		"""data commands group. 1 Sub-classes, 1 commands."""
 		if not hasattr(self, '_data'):
-			from .Data import Data
-			self._data = Data(self._core, self._cmd_group)
+			from .Data import DataCls
+			self._data = DataCls(self._core, self._cmd_group)
 		return self._data
 
 	@property
 	def scapture(self):
 		"""scapture commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_scapture'):
-			from .Scapture import Scapture
-			self._scapture = Scapture(self._core, self._cmd_group)
+			from .Scapture import ScaptureCls
+			self._scapture = ScaptureCls(self._core, self._cmd_group)
 		return self._scapture
 
 	@property
 	def file(self):
 		"""file commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_file'):
-			from .File import File
-			self._file = File(self._core, self._cmd_group)
+			from .File import FileCls
+			self._file = FileCls(self._core, self._cmd_group)
 		return self._file
 
-	def clone(self) -> 'Iq':
+	def clone(self) -> 'IqCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Iq(self._core, self._cmd_group.parent)
+		new_group = IqCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
