@@ -3,7 +3,7 @@ from ....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Master:
+class MasterCls:
 	"""Master commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Master:
 	def port(self):
 		"""port commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_port'):
-			from .Port import Port
-			self._port = Port(self._core, self._cmd_group)
+			from .Port import PortCls
+			self._port = PortCls(self._core, self._cmd_group)
 		return self._port
 
-	def clone(self) -> 'Master':
+	def clone(self) -> 'MasterCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Master(self._core, self._cmd_group.parent)
+		new_group = MasterCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
