@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Time:
+class TimeCls:
 	"""Time commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Time:
 		"""SCPI: TRIGger[:SEQuence]:HOLDoff[:TIME] \n
 		Snippet: driver.trigger.sequence.holdoff.time.set(offset = 1.0) \n
 		Defines the time offset between the trigger event and the start of the measurement. \n
-			:param offset: Unit: S
+			:param offset: For measurements in the frequency domain, the range is 0 s to 30 s. For measurements in the time domain, the range is the negative measurement time to 30 s. Unit: S
 		"""
 		param = Conversions.decimal_value_to_str(offset)
 		self._core.io.write(f'TRIGger:SEQuence:HOLDoff:TIME {param}')
@@ -24,6 +24,6 @@ class Time:
 		"""SCPI: TRIGger[:SEQuence]:HOLDoff[:TIME] \n
 		Snippet: value: float = driver.trigger.sequence.holdoff.time.get() \n
 		Defines the time offset between the trigger event and the start of the measurement. \n
-			:return: offset: Unit: S"""
+			:return: offset: For measurements in the frequency domain, the range is 0 s to 30 s. For measurements in the time domain, the range is the negative measurement time to 30 s. Unit: S"""
 		response = self._core.io.query_str(f'TRIGger:SEQuence:HOLDoff:TIME?')
 		return Conversions.str_to_float(response)
