@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Holdoff:
+class HoldoffCls:
 	"""Holdoff commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class Holdoff:
 	def time(self):
 		"""time commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_time'):
-			from .Time import Time
-			self._time = Time(self._core, self._cmd_group)
+			from .Time import TimeCls
+			self._time = TimeCls(self._core, self._cmd_group)
 		return self._time
 
-	def clone(self) -> 'Holdoff':
+	def clone(self) -> 'HoldoffCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Holdoff(self._core, self._cmd_group.parent)
+		new_group = HoldoffCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
