@@ -3,7 +3,7 @@ from .....Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class RfPower:
+class RfPowerCls:
 	"""RfPower commands group definition. 1 total commands, 1 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,14 +14,14 @@ class RfPower:
 	def holdoff(self):
 		"""holdoff commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_holdoff'):
-			from .Holdoff import Holdoff
-			self._holdoff = Holdoff(self._core, self._cmd_group)
+			from .Holdoff import HoldoffCls
+			self._holdoff = HoldoffCls(self._core, self._cmd_group)
 		return self._holdoff
 
-	def clone(self) -> 'RfPower':
+	def clone(self) -> 'RfPowerCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = RfPower(self._core, self._cmd_group.parent)
+		new_group = RfPowerCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
