@@ -4,7 +4,7 @@ from .....Internal import Conversions
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Rinterval:
+class RintervalCls:
 	"""Rinterval commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -15,7 +15,7 @@ class Rinterval:
 		"""SCPI: TRIGger[:SEQuence]:TIME:RINTerval \n
 		Snippet: driver.trigger.sequence.time.rinterval.set(interval = 1.0) \n
 		This command defines the repetition interval for the time trigger. \n
-			:param interval: 2.0 ms to 5000 Range: 2 ms to 5000 s, Unit: S
+			:param interval: numeric value Range: 2 ms to 5000 s, Unit: S
 		"""
 		param = Conversions.decimal_value_to_str(interval)
 		self._core.io.write(f'TRIGger:SEQuence:TIME:RINTerval {param}')
@@ -24,6 +24,6 @@ class Rinterval:
 		"""SCPI: TRIGger[:SEQuence]:TIME:RINTerval \n
 		Snippet: value: float = driver.trigger.sequence.time.rinterval.get() \n
 		This command defines the repetition interval for the time trigger. \n
-			:return: interval: 2.0 ms to 5000 Range: 2 ms to 5000 s, Unit: S"""
+			:return: interval: numeric value Range: 2 ms to 5000 s, Unit: S"""
 		response = self._core.io.query_str(f'TRIGger:SEQuence:TIME:RINTerval?')
 		return Conversions.str_to_float(response)
