@@ -3,7 +3,7 @@ from ..Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class TriggerInvoke:
+class TriggerInvokeCls:
 	"""TriggerInvoke commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""
 
 	def __init__(self, core: Core, parent):
