@@ -3,7 +3,7 @@ from ...Internal.CommandsGroup import CommandsGroup
 
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
-class Unit:
+class UnitCls:
 	"""Unit commands group definition. 4 total commands, 3 Subgroups, 0 group commands"""
 
 	def __init__(self, core: Core, parent):
@@ -14,30 +14,30 @@ class Unit:
 	def thd(self):
 		"""thd commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_thd'):
-			from .Thd import Thd
-			self._thd = Thd(self._core, self._cmd_group)
+			from .Thd import ThdCls
+			self._thd = ThdCls(self._core, self._cmd_group)
 		return self._thd
 
 	@property
 	def pmeter(self):
 		"""pmeter commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_pmeter'):
-			from .Pmeter import Pmeter
-			self._pmeter = Pmeter(self._core, self._cmd_group)
+			from .Pmeter import PmeterCls
+			self._pmeter = PmeterCls(self._core, self._cmd_group)
 		return self._pmeter
 
 	@property
 	def angle(self):
 		"""angle commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_angle'):
-			from .Angle import Angle
-			self._angle = Angle(self._core, self._cmd_group)
+			from .Angle import AngleCls
+			self._angle = AngleCls(self._core, self._cmd_group)
 		return self._angle
 
-	def clone(self) -> 'Unit':
+	def clone(self) -> 'UnitCls':
 		"""Clones the group by creating new object from it and its whole existing subgroups
 		Also copies all the existing default Repeated Capabilities setting,
 		which you can change independently without affecting the original group"""
-		new_group = Unit(self._core, self._cmd_group.parent)
+		new_group = UnitCls(self._core, self._cmd_group.parent)
 		self._cmd_group.synchronize_repcaps(new_group)
 		return new_group
