@@ -695,3 +695,29 @@ class ScpiLogger:
 
     def __del__(self):
         self.flush()
+
+    def sync_from(self, source: 'ScpiLogger') -> None:
+        """Synchronises this Logger with the source."""
+        self._orig_resource_name = source._orig_resource_name
+        self.mode = source.mode
+        self.default_mode = source.default_mode
+        self.log_status_check_ok = source.log_status_check_ok
+        self.log_to_console = source.log_to_console
+        self.log_to_udp = source.log_to_udp
+        self.udp_port = source.udp_port
+        self.set_format_string(source._format_string, source._line_divider)
+        self._target_auto_flushing = source._target_auto_flushing
+
+        self._log_target_local = source._log_target_local
+        self._timestamp_reference_time_local = source._timestamp_reference_time_local
+        if source._global_mode is True:
+            self.set_logging_target_global()
+
+        # Public properties
+        self.device_name = source.device_name
+        self.abbreviated_max_len_ascii = source.abbreviated_max_len_ascii
+        self.abbreviated_max_len_list = source.abbreviated_max_len_list
+        self.abbreviated_max_len_bin = source.abbreviated_max_len_bin
+        self.bin_line_block_size = source.bin_line_block_size
+        self.encoding = source.encoding
+        self.allow_log_string_adjust = source.allow_log_string_adjust
