@@ -9,8 +9,8 @@ from datetime import datetime, timedelta
 
 # noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
 class RsFswp:
-	"""2599 total commands, 24 Subgroups, 1 group commands"""
-	_driver_options = "SupportedInstrModels = FSWP/FSPN, SupportedIdnPatterns = FSWP/FSPN, SimulationIdnString = Rohde&Schwarz*FSWP50*100001*2.0.1.0003"
+	"""2627 total commands, 24 Subgroups, 1 group commands"""
+	_driver_options = "SupportedInstrModels = FSWP/FSPN, SupportedIdnPatterns = FSWP/FSPN, SimulationIdnString = Rohde&Schwarz*FSWP50*100001*3.0.0.0006"
 	_global_logging_relative_timestamp: ClassVar[datetime] = None
 	_global_logging_target_stream: ClassVar = None
 
@@ -45,7 +45,7 @@ class RsFswp:
 		:param options: string tokens alternating the driver settings.
 		:param direct_session: Another driver object or pyVisa object to reuse the session instead of opening a new session."""
 		self._core = Core(resource_name, id_query, reset, RsFswp._driver_options, options, direct_session)
-		self._core.driver_version = '2.0.1.0003'
+		self._core.driver_version = '3.0.0.0006'
 		self._options = options
 		self._add_all_global_repcaps()
 		self._custom_properties_init()
@@ -59,7 +59,10 @@ class RsFswp:
 		:param session: can be another driver or a direct pyvisa session.
 		:param options: string tokens alternating the driver settings."""
 		# noinspection PyTypeChecker
-		return cls(None, False, False, options, session)
+		resource_name = None
+		if hasattr(session, 'resource_name'):
+			resource_name = getattr(session, 'resource_name')
+		return cls(resource_name, False, False, options, session)
 		
 	@classmethod
 	def set_global_logging_target(cls, target) -> None:
@@ -87,6 +90,7 @@ class RsFswp:
 	@classmethod
 	def clear_global_logging_relative_timestamp(cls) -> None:
 		"""Clears the global relative timestamp. After this, all the instances using the global relative timestamp continue logging with the absolute timestamps."""
+		# noinspection PyTypeChecker
 		cls._global_logging_relative_timestamp = None
 
 	@classmethod
@@ -121,7 +125,7 @@ class RsFswp:
 		"""Asserts that the driver version fulfills the minimum required version you have entered.
 		This way you make sure your installed driver is of the entered version or newer."""
 		min_version_list = min_version.split('.')
-		curr_version_list = '2.0.1.0003'.split('.')
+		curr_version_list = '3.0.0.0006'.split('.')
 		count_min = len(min_version_list)
 		count_curr = len(curr_version_list)
 		count = count_min if count_min < count_curr else count_curr
@@ -131,7 +135,7 @@ class RsFswp:
 			if curr > minimum:
 				break
 			if curr < minimum:
-				raise RsInstrException(f"Assertion for minimum RsFswp version failed. Current version: '2.0.1.0003', minimum required version: '{min_version}'")
+				raise RsInstrException(f"Assertion for minimum RsFswp version failed. Current version: '3.0.0.0006', minimum required version: '{min_version}'")
 
 	@staticmethod
 	def list_resources(expression: str = '?*::INSTR', visa_select: str = None) -> List[str]:
@@ -159,203 +163,208 @@ class RsFswp:
 	def _add_all_global_repcaps(self) -> None:
 		"""Adds all the repcaps defined as global to the instrument's global repcaps dictionary."""
 
-	def _custom_properties_init(self):
+	def _custom_properties_init(self) -> None:
 		"""Adds all the interfaces that are custom for the driver."""
 		from .CustomFiles.utilities import Utilities
 		self.utilities = Utilities(self._core)
 		from .CustomFiles.events import Events
 		self.events = Events(self._core)
+		
+	def _sync_to_custom_properties(self, cloned: 'RsFswp') -> None:
+		"""Synchronises the state of all the custom properties to the entered object."""
+		cloned.utilities.sync_from(self.utilities)
+		cloned.events.sync_from(self.events)
 
 	@property
 	def layout(self):
 		"""layout commands group. 7 Sub-classes, 0 commands."""
 		if not hasattr(self, '_layout'):
-			from .Implementations.Layout import Layout
-			self._layout = Layout(self._core, self._cmd_group)
+			from .Implementations.Layout import LayoutCls
+			self._layout = LayoutCls(self._core, self._cmd_group)
 		return self._layout
 
 	@property
 	def massMemory(self):
 		"""massMemory commands group. 14 Sub-classes, 3 commands."""
 		if not hasattr(self, '_massMemory'):
-			from .Implementations.MassMemory import MassMemory
-			self._massMemory = MassMemory(self._core, self._cmd_group)
+			from .Implementations.MassMemory import MassMemoryCls
+			self._massMemory = MassMemoryCls(self._core, self._cmd_group)
 		return self._massMemory
 
 	@property
 	def sense(self):
 		"""sense commands group. 26 Sub-classes, 0 commands."""
 		if not hasattr(self, '_sense'):
-			from .Implementations.Sense import Sense
-			self._sense = Sense(self._core, self._cmd_group)
+			from .Implementations.Sense import SenseCls
+			self._sense = SenseCls(self._core, self._cmd_group)
 		return self._sense
 
 	@property
 	def calculate(self):
 		"""calculate commands group. 13 Sub-classes, 0 commands."""
 		if not hasattr(self, '_calculate'):
-			from .Implementations.Calculate import Calculate
-			self._calculate = Calculate(self._core, self._cmd_group)
+			from .Implementations.Calculate import CalculateCls
+			self._calculate = CalculateCls(self._core, self._cmd_group)
 		return self._calculate
 
 	@property
 	def instrument(self):
 		"""instrument commands group. 8 Sub-classes, 2 commands."""
 		if not hasattr(self, '_instrument'):
-			from .Implementations.Instrument import Instrument
-			self._instrument = Instrument(self._core, self._cmd_group)
+			from .Implementations.Instrument import InstrumentCls
+			self._instrument = InstrumentCls(self._core, self._cmd_group)
 		return self._instrument
 
 	@property
 	def trace(self):
 		"""trace commands group. 2 Sub-classes, 1 commands."""
 		if not hasattr(self, '_trace'):
-			from .Implementations.Trace import Trace
-			self._trace = Trace(self._core, self._cmd_group)
+			from .Implementations.Trace import TraceCls
+			self._trace = TraceCls(self._core, self._cmd_group)
 		return self._trace
 
 	@property
 	def display(self):
 		"""display commands group. 17 Sub-classes, 0 commands."""
 		if not hasattr(self, '_display'):
-			from .Implementations.Display import Display
-			self._display = Display(self._core, self._cmd_group)
+			from .Implementations.Display import DisplayCls
+			self._display = DisplayCls(self._core, self._cmd_group)
 		return self._display
 
 	@property
 	def system(self):
-		"""system commands group. 28 Sub-classes, 0 commands."""
+		"""system commands group. 29 Sub-classes, 0 commands."""
 		if not hasattr(self, '_system'):
-			from .Implementations.System import System
-			self._system = System(self._core, self._cmd_group)
+			from .Implementations.System import SystemCls
+			self._system = SystemCls(self._core, self._cmd_group)
 		return self._system
 
 	@property
 	def formatPy(self):
 		"""formatPy commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_formatPy'):
-			from .Implementations.FormatPy import FormatPy
-			self._formatPy = FormatPy(self._core, self._cmd_group)
+			from .Implementations.FormatPy import FormatPyCls
+			self._formatPy = FormatPyCls(self._core, self._cmd_group)
 		return self._formatPy
 
 	@property
 	def inputPy(self):
-		"""inputPy commands group. 16 Sub-classes, 0 commands."""
+		"""inputPy commands group. 17 Sub-classes, 0 commands."""
 		if not hasattr(self, '_inputPy'):
-			from .Implementations.InputPy import InputPy
-			self._inputPy = InputPy(self._core, self._cmd_group)
+			from .Implementations.InputPy import InputPyCls
+			self._inputPy = InputPyCls(self._core, self._cmd_group)
 		return self._inputPy
 
 	@property
 	def status(self):
 		"""status commands group. 3 Sub-classes, 1 commands."""
 		if not hasattr(self, '_status'):
-			from .Implementations.Status import Status
-			self._status = Status(self._core, self._cmd_group)
+			from .Implementations.Status import StatusCls
+			self._status = StatusCls(self._core, self._cmd_group)
 		return self._status
 
 	@property
 	def applications(self):
 		"""applications commands group. 7 Sub-classes, 0 commands."""
 		if not hasattr(self, '_applications'):
-			from .Implementations.Applications import Applications
-			self._applications = Applications(self._core, self._cmd_group)
+			from .Implementations.Applications import ApplicationsCls
+			self._applications = ApplicationsCls(self._core, self._cmd_group)
 		return self._applications
 
 	@property
 	def calibration(self):
-		"""calibration commands group. 4 Sub-classes, 0 commands."""
+		"""calibration commands group. 5 Sub-classes, 0 commands."""
 		if not hasattr(self, '_calibration'):
-			from .Implementations.Calibration import Calibration
-			self._calibration = Calibration(self._core, self._cmd_group)
+			from .Implementations.Calibration import CalibrationCls
+			self._calibration = CalibrationCls(self._core, self._cmd_group)
 		return self._calibration
 
 	@property
 	def output(self):
 		"""output commands group. 6 Sub-classes, 0 commands."""
 		if not hasattr(self, '_output'):
-			from .Implementations.Output import Output
-			self._output = Output(self._core, self._cmd_group)
+			from .Implementations.Output import OutputCls
+			self._output = OutputCls(self._core, self._cmd_group)
 		return self._output
 
 	@property
 	def trigger(self):
 		"""trigger commands group. 4 Sub-classes, 0 commands."""
 		if not hasattr(self, '_trigger'):
-			from .Implementations.Trigger import Trigger
-			self._trigger = Trigger(self._core, self._cmd_group)
+			from .Implementations.Trigger import TriggerCls
+			self._trigger = TriggerCls(self._core, self._cmd_group)
 		return self._trigger
 
 	@property
 	def triggerInvoke(self):
 		"""triggerInvoke commands group. 0 Sub-classes, 1 commands."""
 		if not hasattr(self, '_triggerInvoke'):
-			from .Implementations.TriggerInvoke import TriggerInvoke
-			self._triggerInvoke = TriggerInvoke(self._core, self._cmd_group)
+			from .Implementations.TriggerInvoke import TriggerInvokeCls
+			self._triggerInvoke = TriggerInvokeCls(self._core, self._cmd_group)
 		return self._triggerInvoke
 
 	@property
 	def configure(self):
 		"""configure commands group. 2 Sub-classes, 0 commands."""
 		if not hasattr(self, '_configure'):
-			from .Implementations.Configure import Configure
-			self._configure = Configure(self._core, self._cmd_group)
+			from .Implementations.Configure import ConfigureCls
+			self._configure = ConfigureCls(self._core, self._cmd_group)
 		return self._configure
 
 	@property
 	def fetch(self):
 		"""fetch commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_fetch'):
-			from .Implementations.Fetch import Fetch
-			self._fetch = Fetch(self._core, self._cmd_group)
+			from .Implementations.Fetch import FetchCls
+			self._fetch = FetchCls(self._core, self._cmd_group)
 		return self._fetch
 
 	@property
 	def initiate(self):
 		"""initiate commands group. 6 Sub-classes, 1 commands."""
 		if not hasattr(self, '_initiate'):
-			from .Implementations.Initiate import Initiate
-			self._initiate = Initiate(self._core, self._cmd_group)
+			from .Implementations.Initiate import InitiateCls
+			self._initiate = InitiateCls(self._core, self._cmd_group)
 		return self._initiate
 
 	@property
 	def read(self):
 		"""read commands group. 1 Sub-classes, 0 commands."""
 		if not hasattr(self, '_read'):
-			from .Implementations.Read import Read
-			self._read = Read(self._core, self._cmd_group)
+			from .Implementations.Read import ReadCls
+			self._read = ReadCls(self._core, self._cmd_group)
 		return self._read
 
 	@property
 	def source(self):
 		"""source commands group. 6 Sub-classes, 0 commands."""
 		if not hasattr(self, '_source'):
-			from .Implementations.Source import Source
-			self._source = Source(self._core, self._cmd_group)
+			from .Implementations.Source import SourceCls
+			self._source = SourceCls(self._core, self._cmd_group)
 		return self._source
 
 	@property
 	def unit(self):
 		"""unit commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_unit'):
-			from .Implementations.Unit import Unit
-			self._unit = Unit(self._core, self._cmd_group)
+			from .Implementations.Unit import UnitCls
+			self._unit = UnitCls(self._core, self._cmd_group)
 		return self._unit
 
 	@property
 	def hardCopy(self):
-		"""hardCopy commands group. 14 Sub-classes, 1 commands."""
+		"""hardCopy commands group. 15 Sub-classes, 1 commands."""
 		if not hasattr(self, '_hardCopy'):
-			from .Implementations.HardCopy import HardCopy
-			self._hardCopy = HardCopy(self._core, self._cmd_group)
+			from .Implementations.HardCopy import HardCopyCls
+			self._hardCopy = HardCopyCls(self._core, self._cmd_group)
 		return self._hardCopy
 
 	@property
 	def diagnostic(self):
 		"""diagnostic commands group. 3 Sub-classes, 0 commands."""
 		if not hasattr(self, '_diagnostic'):
-			from .Implementations.Diagnostic import Diagnostic
-			self._diagnostic = Diagnostic(self._core, self._cmd_group)
+			from .Implementations.Diagnostic import DiagnosticCls
+			self._diagnostic = DiagnosticCls(self._core, self._cmd_group)
 		return self._diagnostic
 
 	def abort(self) -> None:
@@ -363,13 +372,14 @@ class RsFswp:
 		Snippet: driver.abort() \n
 		This command aborts the measurement in the current channel and resets the trigger system. To prevent overlapping
 		execution of the subsequent command before the measurement has been aborted successfully, use the *OPC? or *WAI command
-		after method RsFswp.#Abort CMDLINKRESOLVED] and before the next command. To abort a sequence of measurements by the
-		Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort command. Note on blocked remote control programs: If a
-		sequential command cannot be completed, for example because a triggered sweep never receives a trigger, the remote
-		control program will never finish and the remote channel to the R&S FSWP is blocked for further commands. In this case,
-		you must interrupt processing on the remote channel first in order to abort the measurement. To do so, send a 'Device
-		Clear' command from the control instrument to the R&S FSWP on a parallel channel to clear all currently active remote
-		channels. Depending on the used interface and protocol, send the following commands:
+		after method RsFswp.#Abort CMDLINKRESOLVED] and before the next command. For details on overlapping execution see Remote
+		control via SCPI. To abort a sequence of measurements by the Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort
+		command. Note on blocked remote control programs: If a sequential command cannot be completed, for example because a
+		triggered sweep never receives a trigger, the remote control program will never finish and the remote channel to the R&S
+		FSWP is blocked for further commands. In this case, you must interrupt processing on the remote channel first in order to
+		abort the measurement. To do so, send a 'Device Clear' command from the control instrument to the R&S FSWP on a parallel
+		channel to clear all currently active remote channels. Depending on the used interface and protocol, send the following
+		commands:
 			- Visa: viClear
 			- GPIB: ibclr
 			- RSIB: RSDLLibclr
@@ -382,13 +392,14 @@ class RsFswp:
 		Snippet: driver.abort_with_opc() \n
 		This command aborts the measurement in the current channel and resets the trigger system. To prevent overlapping
 		execution of the subsequent command before the measurement has been aborted successfully, use the *OPC? or *WAI command
-		after method RsFswp.#Abort CMDLINKRESOLVED] and before the next command. To abort a sequence of measurements by the
-		Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort command. Note on blocked remote control programs: If a
-		sequential command cannot be completed, for example because a triggered sweep never receives a trigger, the remote
-		control program will never finish and the remote channel to the R&S FSWP is blocked for further commands. In this case,
-		you must interrupt processing on the remote channel first in order to abort the measurement. To do so, send a 'Device
-		Clear' command from the control instrument to the R&S FSWP on a parallel channel to clear all currently active remote
-		channels. Depending on the used interface and protocol, send the following commands:
+		after method RsFswp.#Abort CMDLINKRESOLVED] and before the next command. For details on overlapping execution see Remote
+		control via SCPI. To abort a sequence of measurements by the Sequencer, use the [CMDLINKRESOLVED Initiate.Sequencer.abort
+		command. Note on blocked remote control programs: If a sequential command cannot be completed, for example because a
+		triggered sweep never receives a trigger, the remote control program will never finish and the remote channel to the R&S
+		FSWP is blocked for further commands. In this case, you must interrupt processing on the remote channel first in order to
+		abort the measurement. To do so, send a 'Device Clear' command from the control instrument to the R&S FSWP on a parallel
+		channel to clear all currently active remote channels. Depending on the used interface and protocol, send the following
+		commands:
 			- Visa: viClear
 			- GPIB: ibclr
 			- RSIB: RSDLLibclr
@@ -407,6 +418,7 @@ class RsFswp:
 		cloned = RsFswp.from_existing_session(self.get_session_handle(), self._options)
 		self._cmd_group.synchronize_repcaps(cloned)
 		
+		self._sync_to_custom_properties(cloned)
 		return cloned
 
 	def restore_all_repcaps_to_default(self) -> None:
