@@ -171,6 +171,13 @@ class BerRateFormat(Enum):
 	TTOTal = 16
 
 
+# noinspection SpellCheckingInspection
+class BitOrdering(Enum):
+	"""2 Members, LSB ... MSB"""
+	LSB = 0
+	MSB = 1
+
+
 # noinspection SpellCheckingInspection
 class BurstMode(Enum):
 	"""2 Members, BURS ... MEAS"""
@@ -271,16 +278,18 @@ class ColorSchemeA(Enum):
 
 # noinspection SpellCheckingInspection
 class CompatibilityMode(Enum):
-	"""9 Members, ATT ... FSW"""
+	"""11 Members, ATT ... FSWXv1_0"""
 	ATT = 0
 	DEFault = 1
 	FSET = 2
 	FSL = 3
-	FSP = 4
-	FSQ = 5
-	FSU = 6
-	FSV = 7
-	FSW = 8
+	FSMR = 4
+	FSP = 5
+	FSQ = 6
+	FSU = 7
+	FSV = 8
+	FSW = 9
+	FSWXv1_0 = 10
 
 
 # noinspection SpellCheckingInspection
@@ -364,6 +373,19 @@ class DataFormat(Enum):
 	UINT_cma_64 = 9
 
 
+# noinspection SpellCheckingInspection
+class DaysOfWeek(Enum):
+	"""8 Members, ALL ... WEDNesday"""
+	ALL = 0
+	FRIDay = 1
+	MONDay = 2
+	SATurday = 3
+	SUNDay = 4
+	THURsday = 5
+	TUESday = 6
+	WEDNesday = 7
+
+
 # noinspection SpellCheckingInspection
 class DdemGroup(Enum):
 	"""8 Members, APSK ... UQAM"""
@@ -950,38 +972,6 @@ class LimitState(Enum):
 	RELative = 3
 
 
-# noinspection SpellCheckingInspection
-class LimitUnit(Enum):
-	"""27 Members, A ... WATT"""
-	A = 0
-	AMPere = 1
-	DB = 2
-	DBM = 3
-	DBM_mhz = 4
-	DBMV = 5
-	DBMV_mhz = 6
-	DBPT = 7
-	DBPT_mhz = 8
-	DBPW = 9
-	DBPW_mhz = 10
-	DBUA = 11
-	DBUa_m = 12
-	DBUa_mhz = 13
-	DBUa_mmhz = 14
-	DBUV = 15
-	DBUV_m = 16
-	DBUV_mhz = 17
-	DBUV_mmhz = 18
-	DEG = 19
-	HZ = 20
-	PCT = 21
-	RAD = 22
-	S = 23
-	UNITless = 24
-	VOLT = 25
-	WATT = 26
-
-
 # noinspection SpellCheckingInspection
 class LoadType(Enum):
 	"""2 Members, NEW ... REPLace"""
@@ -1097,6 +1087,13 @@ class MskFormat(Enum):
 	TYPe2 = 3
 
 
+# noinspection SpellCheckingInspection
+class MspurSearchType(Enum):
+	"""2 Members, DMINimum ... PMAXimum"""
+	DMINimum = 0
+	PMAXimum = 1
+
+
 # noinspection SpellCheckingInspection
 class MsSyncMode(Enum):
 	"""5 Members, MASTer ... SLAVe"""
@@ -1202,6 +1199,13 @@ class PageOrientation(Enum):
 	PORTrait = 1
 
 
+# noinspection SpellCheckingInspection
+class PathToCalibrate(Enum):
+	"""2 Members, FULL ... PARTial"""
+	FULL = 0
+	PARTial = 1
+
+
 # noinspection SpellCheckingInspection
 class PictureFormat(Enum):
 	"""11 Members, BMP ... WMF"""
@@ -1261,33 +1265,67 @@ class PowerSource(Enum):
 
 
 # noinspection SpellCheckingInspection
-class PowerUnit(Enum):
-	"""25 Members, A ... WATT"""
+class PowerUnitB(Enum):
+	"""26 Members, A ... WATT"""
 	A = 0
 	AMPere = 1
 	DB = 2
 	DBM = 3
-	DBM_mhz = 4
-	DBMV = 5
-	DBMV_mhz = 6
-	DBPT = 7
-	DBPT_mhz = 8
-	DBPW = 9
-	DBPW_mhz = 10
-	DBUA = 11
-	DBUa_m = 12
-	DBUa_mhz = 13
-	DBUa_mmhz = 14
-	DBUV = 15
-	DBUV_m = 16
-	DBUV_mhz = 17
-	DBUV_mmhz = 18
-	PCT = 19
-	UNITless = 20
-	V = 21
-	VOLT = 22
-	W = 23
-	WATT = 24
+	DBM_hz = 4
+	DBM_mhz = 5
+	DBMV = 6
+	DBMV_mhz = 7
+	DBPT = 8
+	DBPT_mhz = 9
+	DBPW = 10
+	DBPW_mhz = 11
+	DBUA = 12
+	DBUa_m = 13
+	DBUa_mhz = 14
+	DBUa_mmhz = 15
+	DBUV = 16
+	DBUV_m = 17
+	DBUV_mhz = 18
+	DBUV_mmhz = 19
+	PCT = 20
+	UNITless = 21
+	V = 22
+	VOLT = 23
+	W = 24
+	WATT = 25
+
+
+# noinspection SpellCheckingInspection
+class PowerUnitC(Enum):
+	"""28 Members, A ... WATT"""
+	A = 0
+	AMPere = 1
+	DB = 2
+	DBM = 3
+	DBM_hz = 4
+	DBM_mhz = 5
+	DBMV = 6
+	DBMV_mhz = 7
+	DBPT = 8
+	DBPT_mhz = 9
+	DBPW = 10
+	DBPW_mhz = 11
+	DBUA = 12
+	DBUa_m = 13
+	DBUa_mhz = 14
+	DBUa_mmhz = 15
+	DBUV = 16
+	DBUV_m = 17
+	DBUV_mhz = 18
+	DBUV_mmhz = 19
+	DEG = 20
+	HZ = 21
+	PCT = 22
+	RAD = 23
+	S = 24
+	UNITless = 25
+	VOLT = 26
+	WATT = 27
 
 
 # noinspection SpellCheckingInspection
@@ -1462,18 +1500,6 @@ class ReferenceSourceB(Enum):
 	INTernal = 2
 
 
-# noinspection SpellCheckingInspection
-class ReferenceSourceC(Enum):
-	"""7 Members, EXT2 ... RFPower"""
-	EXT2 = 0
-	EXT3 = 1
-	EXTernal = 2
-	IFPower = 3
-	IMMediate = 4
-	IQPower = 5
-	RFPower = 6
-
-
 # noinspection SpellCheckingInspection
 class ReferenceSourceD(Enum):
 	"""4 Members, EXT2 ... IMMediate"""
@@ -1572,6 +1598,15 @@ class Relay(Enum):
 	SWRF1in = 83
 
 
+# noinspection SpellCheckingInspection
+class ResultDevReference(Enum):
+	"""4 Members, CENTer ... PMSettling"""
+	CENTer = 0
+	EDGE = 1
+	FMSettling = 2
+	PMSettling = 3
+
+
 # noinspection SpellCheckingInspection
 class ResultTypeB(Enum):
 	"""4 Members, ALL ... PEAK"""
@@ -1608,6 +1643,26 @@ class ResultTypeStat(Enum):
 	TPEak = 8
 
 
+# noinspection SpellCheckingInspection
+class RoscillatorFreqMode(Enum):
+	"""3 Members, E10 ... VARiable"""
+	E10 = 0
+	E100 = 1
+	VARiable = 2
+
+
+# noinspection SpellCheckingInspection
+class RoscillatorRefOut(Enum):
+	"""7 Members, EXTernal1 ... OFF"""
+	EXTernal1 = 0
+	EXTernal2 = 1
+	O10 = 2
+	O100 = 3
+	O1000 = 4
+	O8000 = 5
+	OFF = 6
+
+
 # noinspection SpellCheckingInspection
 class ScaleYaxisUnit(Enum):
 	"""2 Members, ABS ... PCT"""
@@ -1853,10 +1908,11 @@ class SweepModeC(Enum):
 
 # noinspection SpellCheckingInspection
 class SweepOptimize(Enum):
-	"""3 Members, AUTO ... SPEed"""
+	"""4 Members, AUTO ... TRANsient"""
 	AUTO = 0
 	DYNamic = 1
 	SPEed = 2
+	TRANsient = 3
 
 
 # noinspection SpellCheckingInspection
@@ -1899,7 +1955,7 @@ class SystemStatus(Enum):
 
 # noinspection SpellCheckingInspection
 class TechnologyStandardA(Enum):
-	"""26 Members, GSM ... WCDMa"""
+	"""28 Members, GSM ... WCDMa"""
 	GSM = 0
 	LTE_1_40 = 1
 	LTE_10_00 = 2
@@ -1913,19 +1969,21 @@ class TechnologyStandardA(Enum):
 	NR5G_fr1_20 = 10
 	NR5G_fr1_25 = 11
 	NR5G_fr1_30 = 12
-	NR5G_fr1_40 = 13
-	NR5G_fr1_5 = 14
-	NR5G_fr1_50 = 15
-	NR5G_fr1_60 = 16
-	NR5G_fr1_70 = 17
-	NR5G_fr1_80 = 18
-	NR5G_fr1_90 = 19
-	NR5G_fr2_100 = 20
-	NR5G_fr2_200 = 21
-	NR5G_fr2_400 = 22
-	NR5G_fr2_50 = 23
-	USER = 24
-	WCDMa = 25
+	NR5G_fr1_35 = 13
+	NR5G_fr1_40 = 14
+	NR5G_fr1_45 = 15
+	NR5G_fr1_5 = 16
+	NR5G_fr1_50 = 17
+	NR5G_fr1_60 = 18
+	NR5G_fr1_70 = 19
+	NR5G_fr1_80 = 20
+	NR5G_fr1_90 = 21
+	NR5G_fr2_100 = 22
+	NR5G_fr2_200 = 23
+	NR5G_fr2_400 = 24
+	NR5G_fr2_50 = 25
+	USER = 26
+	WCDMa = 27
 
 
 # noinspection SpellCheckingInspection
@@ -2010,9 +2068,10 @@ class Temperature(Enum):
 
 # noinspection SpellCheckingInspection
 class TimeFormat(Enum):
-	"""2 Members, DE ... US"""
+	"""3 Members, DE ... US"""
 	DE = 0
-	US = 1
+	ISO = 1
+	US = 2
 
 
 # noinspection SpellCheckingInspection
@@ -2362,8 +2421,8 @@ class TriggerSourceD(Enum):
 
 
 # noinspection SpellCheckingInspection
-class TriggerSourceE(Enum):
-	"""8 Members, EXT2 ... RFPower"""
+class TriggerSourceK(Enum):
+	"""9 Members, EXT2 ... TIME"""
 	EXT2 = 0
 	EXT3 = 1
 	EXTernal = 2
@@ -2372,6 +2431,20 @@ class TriggerSourceE(Enum):
 	IQPower = 5
 	MANual = 6
 	RFPower = 7
+	TIME = 8
+
+
+# noinspection SpellCheckingInspection
+class TriggerSourceL(Enum):
+	"""8 Members, EXT2 ... TIME"""
+	EXT2 = 0
+	EXT3 = 1
+	EXTernal = 2
+	IFPower = 3
+	IMMediate = 4
+	IQPower = 5
+	RFPower = 6
+	TIME = 7
 
 
 # noinspection SpellCheckingInspection
