@@ -696,15 +696,6 @@ class OutputConnector(Enum):
 	Nr4 = 4
 
 
-# noinspection SpellCheckingInspection
-class OutputSignal(Enum):
-	"""Repeated capability OutputSignal"""
-	Empty = EmptyRepCap
-	Default = DefaultRepCap
-	Freq100MHz = 100
-	Freq640MHz = 640
-
-
 # noinspection SpellCheckingInspection
 class Port(Enum):
 	"""Repeated capability Port"""
